// ==========================================================================
// Image replacement
// ==========================================================================

@mixin image-replacement($url, $width, $height) {
	// I totally stole this idea from Marcel Shields.
	// Read his article: http://css-tricks.com/replace-the-image-in-an-img-with-css/
	display: block;
	width: $width; // Width of new image
	height: $height; // Height of new image
	padding-left: $width; // Equal to width of new image
	background: url($url) no-repeat;
}