// ==========================================================================
// Automatticons
//
// A quick reference
// ==========================================================================

$automatticons: 'automatticons';

// This font was graciously generated by Font Squirrel (http://www.fontsquirrel.com). We love those guys.
@font-face {
	font-family: 'automatticons';
	src: url('../_inc/fonts/automatticons/automatticons.eot');
	src: url('../_inc/fonts/automatticons/automatticons.eot?#iefix') format('embedded-opentype'),
		url('../_inc/fonts/automatticons/automatticons.woff') format('woff'),
		url('../_inc/fonts/automatticons/automatticons.ttf') format('truetype'),
		url('../_inc/fonts/automatticons/automatticons.svg#automatticonsregular') format('svg');
	font-weight: normal;
	font-style: normal;
}

// $automattic: 'A';
// $code-poet: 'C';
// $facebook: 'F';
// $gravatar: 'G';
// $inferno: 'I'; // Not sure what this one is
// $jetpack: 'J';
// $akismet: 'K';
// $polldaddy: 'P';
// $shield: 's'; // VaultPress shield
// $vaultpress: 'V';
// $vaultpress-inverted: 'v';
// $wordpress: 'W';
