<?php
/**
 * Philippines Provinces
 *
 * @category i18n
 * @package  WooCommerce/i18n
 * @version  2.4.0
 */
global $states;

$states['PH'] = array(
	'ABR' => __( 'Abra', 'woocommerce' ),
	'AGN' => __( 'Agusan del Norte', 'woocommerce' ),
	'AGS' => __( 'Agusan del Sur', 'woocommerce' ),
	'AKL' => __( 'Aklan', 'woocommerce' ),
	'ALB' => __( 'Albay', 'woocommerce' ),
	'ANT' => __( 'Antique', 'woocommerce' ),
	'APA' => __( 'Apayao', 'woocommerce' ),
	'AUR' => __( 'Aurora', 'woocommerce' ),
	'BAS' => __( 'Basilan', 'woocommerce' ),
	'BAN' => __( 'Bataan', 'woocommerce' ),
	'BTN' => __( 'Batanes', 'woocommerce' ),
	'BTG' => __( 'Batangas', 'woocommerce' ),
	'BEN' => __( 'Benguet', 'woocommerce' ),
	'BIL' => __( 'Biliran', 'woocommerce' ),
	'BOH' => __( 'Bohol', 'woocommerce' ),
	'BUK' => __( 'Bukidnon', 'woocommerce' ),
	'BUL' => __( 'Bulacan', 'woocommerce' ),
	'CAG' => __( 'Cagayan', 'woocommerce' ),
	'CAN' => __( 'Camarines Norte', 'woocommerce' ),
	'CAS' => __( 'Camarines Sur', 'woocommerce' ),
	'CAM' => __( 'Camiguin', 'woocommerce' ),
	'CAP' => __( 'Capiz', 'woocommerce' ),
	'CAT' => __( 'Catanduanes', 'woocommerce' ),
	'CAV' => __( 'Cavite', 'woocommerce' ),
	'CEB' => __( 'Cebu', 'woocommerce' ),
	'COM' => __( 'Compostela Valley', 'woocommerce' ),
	'NCO' => __( 'Cotabato', 'woocommerce' ),
	'DAV' => __( 'Davao del Norte', 'woocommerce' ),
	'DAS' => __( 'Davao del Sur', 'woocommerce' ),
	'DAC' => __( 'Davao Occidental', 'woocommerce' ), // TODO: Needs to be updated when ISO code is assigned
	'DAO' => __( 'Davao Oriental', 'woocommerce' ),
	'DIN' => __( 'Dinagat Islands', 'woocommerce' ),
	'EAS' => __( 'Eastern Samar', 'woocommerce' ),
	'GUI' => __( 'Guimaras', 'woocommerce' ),
	'IFU' => __( 'Ifugao', 'woocommerce' ),
	'ILN' => __( 'Ilocos Norte', 'woocommerce' ),
	'ILS' => __( 'Ilocos Sur', 'woocommerce' ),
	'ILI' => __( 'Iloilo', 'woocommerce' ),
	'ISA' => __( 'Isabela', 'woocommerce' ),
	'KAL' => __( 'Kalinga', 'woocommerce' ),
	'LUN' => __( 'La Union', 'woocommerce' ),
	'LAG' => __( 'Laguna', 'woocommerce' ),
	'LAN' => __( 'Lanao del Norte', 'woocommerce' ),
	'LAS' => __( 'Lanao del Sur', 'woocommerce' ),
	'LEY' => __( 'Leyte', 'woocommerce' ),
	'MAG' => __( 'Maguindanao', 'woocommerce' ),
	'MAD' => __( 'Marinduque', 'woocommerce' ),
	'MAS' => __( 'Masbate', 'woocommerce' ),
	'MSC' => __( 'Misamis Occidental', 'woocommerce' ),
	'MSR' => __( 'Misamis Oriental', 'woocommerce' ),
	'MOU' => __( 'Mountain Province', 'woocommerce' ),
	'NEC' => __( 'Negros Occidental', 'woocommerce' ),
	'NER' => __( 'Negros Oriental', 'woocommerce' ),
	'NSA' => __( 'Northern Samar', 'woocommerce' ),
	'NUE' => __( 'Nueva Ecija', 'woocommerce' ),
	'NUV' => __( 'Nueva Vizcaya', 'woocommerce' ),
	'MDC' => __( 'Occidental Mindoro', 'woocommerce' ),
	'MDR' => __( 'Oriental Mindoro', 'woocommerce' ),
	'PLW' => __( 'Palawan', 'woocommerce' ),
	'PAM' => __( 'Pampanga', 'woocommerce' ),
	'PAN' => __( 'Pangasinan', 'woocommerce' ),
	'QUE' => __( 'Quezon', 'woocommerce' ),
	'QUI' => __( 'Quirino', 'woocommerce' ),
	'RIZ' => __( 'Rizal', 'woocommerce' ),
	'ROM' => __( 'Romblon', 'woocommerce' ),
	'WSA' => __( 'Samar', 'woocommerce' ),
	'SAR' => __( 'Sarangani', 'woocommerce' ),
	'SIQ' => __( 'Siquijor', 'woocommerce' ),
	'SOR' => __( 'Sorsogon', 'woocommerce' ),
	'SCO' => __( 'South Cotabato', 'woocommerce' ),
	'SLE' => __( 'Southern Leyte', 'woocommerce' ),
	'SUK' => __( 'Sultan Kudarat', 'woocommerce' ),
	'SLU' => __( 'Sulu', 'woocommerce' ),
	'SUN' => __( 'Surigao del Norte', 'woocommerce' ),
	'SUR' => __( 'Surigao del Sur', 'woocommerce' ),
	'TAR' => __( 'Tarlac', 'woocommerce' ),
	'TAW' => __( 'Tawi-Tawi', 'woocommerce' ),
	'ZMB' => __( 'Zambales', 'woocommerce' ),
	'ZAN' => __( 'Zamboanga del Norte', 'woocommerce' ),
	'ZAS' => __( 'Zamboanga del Sur', 'woocommerce' ),
	'ZSI' => __( 'Zamboanga Sibugay', 'woocommerce' ),
	'00'  => __( 'Metro Manila', 'woocommerce' ),
);
