<?php
/**
 * Indian states
 *
 * @author      WooThemes
 * @category    i18n
 * @package     WooCommerce/i18n
 * @version     2.0.0
 */
global $states;

$states['IN'] = array(
	'AP' => __( 'Andhra Pradesh', 'woocommerce' ),
	'AR' => __( 'Arunachal Pradesh', 'woocommerce' ),
	'AS' => __( 'Assam', 'woocommerce' ),
	'BR' => __( 'Bihar', 'woocommerce' ),
	'CT' => __( 'Chhattisgarh', 'woocommerce' ),
	'GA' => __( 'Goa', 'woocommerce' ),
	'GJ' => __( 'Gujarat', 'woocommerce' ),
	'HR' => __( 'Haryana', 'woocommerce' ),
	'HP' => __( 'Himachal Pradesh', 'woocommerce' ),
	'JK' => __( 'Jammu and Kashmir', 'woocommerce' ),
	'JH' => __( 'Jharkhand', 'woocommerce' ),
	'KA' => __( 'Karnataka', 'woocommerce' ),
	'KL' => __( 'Kerala', 'woocommerce' ),
	'MP' => __( 'Madhya Pradesh', 'woocommerce' ),
	'MH' => __( 'Maharashtra', 'woocommerce' ),
	'MN' => __( 'Manipur', 'woocommerce' ),
	'ML' => __( 'Meghalaya', 'woocommerce' ),
	'MZ' => __( 'Mizoram', 'woocommerce' ),
	'NL' => __( 'Nagaland', 'woocommerce' ),
	'OR' => __( 'Orissa', 'woocommerce' ),
	'PB' => __( 'Punjab', 'woocommerce' ),
	'RJ' => __( 'Rajasthan', 'woocommerce' ),
	'SK' => __( 'Sikkim', 'woocommerce' ),
	'TN' => __( 'Tamil Nadu', 'woocommerce' ),
	'TS' => __( 'Telangana', 'woocommerce' ),
	'TR' => __( 'Tripura', 'woocommerce' ),
	'UK' => __( 'Uttarakhand', 'woocommerce' ),
	'UP' => __( 'Uttar Pradesh', 'woocommerce' ),
	'WB' => __( 'West Bengal', 'woocommerce' ),
	'AN' => __( 'Andaman and Nicobar Islands', 'woocommerce' ),
	'CH' => __( 'Chandigarh', 'woocommerce' ),
	'DN' => __( 'Dadar and Nagar Haveli', 'woocommerce' ),
	'DD' => __( 'Daman and Diu', 'woocommerce' ),
	'DL' => __( 'Delhi', 'woocommerce' ),
	'LD' => __( 'Lakshadeep', 'woocommerce' ),
	'PY' => __( 'Pondicherry (Puducherry)', 'woocommerce' )
);
