/**
 * _fonts.scss
 * Custom WooCommerce fonts.
 */
@font-face {
	font-family: 'star';
	src: url('../fonts/star.eot');
	src: url('../fonts/star.eot?#iefix') format('embedded-opentype'),
		url('../fonts/star.woff') format('woff'),
		url('../fonts/star.ttf') format('truetype'),
		url('../fonts/star.svg#star') format('svg');
	font-weight: normal;
	font-style: normal;
}

@font-face {
	font-family: 'WooCommerce';
	src: url('../fonts/WooCommerce.eot');
	src: url('../fonts/WooCommerce.eot?#iefix') format('embedded-opentype'),
		url('../fonts/WooCommerce.woff') format('woff'),
		url('../fonts/WooCommerce.ttf') format('truetype'),
		url('../fonts/WooCommerce.svg#WooCommerce') format('svg');
	font-weight: normal;
	font-style: normal;
}