<?php
/**
 * Iran States
 *
 * @author      WooThemes
 * @category    i18n
 * @package     WooCommerce/i18n
 * @version     2.2.3
 */
global $states;

$states['IR'] = array(
	'KHZ' => __( 'Khuzestan  (خوزستان)', 'woocommerce' ),
	'THR' => __( 'Tehran  (تهران)', 'woocommerce' ),
	'ILM' => __( 'Ilaam (ایلام)', 'woocommerce' ),
	'BHR' => __( 'Bushehr (بوشهر)', 'woocommerce' ),
	'ADL' => __( 'Ardabil (اردبیل)', 'woocommerce' ),
	'ESF' => __( 'Isfahan (اصفهان)', 'woocommerce' ),
	'YZD' => __( 'Yazd (یزد)', 'woocommerce' ),
	'KRH' => __( 'Kermanshah (کرمانشاه)', 'woocommerce' ),
	'KRN' => __( 'Kerman (کرمان)', 'woocommerce' ),
	'HDN' => __( 'Hamadan (همدان)', 'woocommerce' ),
	'GZN' => __( 'Ghazvin (قزوین)', 'woocommerce' ),
	'ZJN' => __( 'Zanjan (زنجان)', 'woocommerce' ),
	'LRS' => __( 'Luristan (لرستان)', 'woocommerce' ),
	'ABZ' => __( 'Alborz (البرز)', 'woocommerce' ),
	'EAZ' => __( 'East Azarbaijan (آذربایجان شرقی)', 'woocommerce' ),
	'WAZ' => __( 'West Azarbaijan (آذربایجان غربی)', 'woocommerce' ),
	'CHB' => __( 'Chaharmahal and Bakhtiari (چهارمحال و بختیاری)', 'woocommerce' ),
	'SKH' => __( 'South Khorasan (خراسان جنوبی)', 'woocommerce' ),
	'RKH' => __( 'Razavi Khorasan (خراسان رضوی)', 'woocommerce' ),
	'NKH' => __( 'North Khorasan (خراسان جنوبی)', 'woocommerce' ),
	'SMN' => __( 'Semnan (سمنان)', 'woocommerce' ),
	'FRS' => __( 'Fars (فارس)', 'woocommerce' ),
	'QHM' => __( 'Qom (قم)', 'woocommerce' ),
	'KRD' => __( 'Kurdistan / کردستان)', 'woocommerce' ),
	'KBD' => __( 'Kohgiluyeh and BoyerAhmad (کهگیلوییه و بویراحمد)', 'woocommerce' ),
	'GLS' => __( 'Golestan (گلستان)', 'woocommerce' ),
	'GIL' => __( 'Gilan (گیلان)', 'woocommerce' ),
	'MZN' => __( 'Mazandaran (مازندران)', 'woocommerce' ),
	'MKZ' => __( 'Markazi (مرکزی)', 'woocommerce' ),
	'HRZ' => __( 'Hormozgan (هرمزگان)', 'woocommerce' ),
	'SBN' => __( 'Sistan and Baluchestan (سیستان و بلوچستان)', 'woocommerce' )
);
