/**
 * RTL styles for the Site Logo control. Just swaps the button sides.
 */
#customize-control-site_logo .remove {
	float: right;
	margin-left: 3px;
}

#customize-control-site_logo .new,
#customize-control-site_logo .change {
	float: left;
}
