<?php
/**
 * Bangladeshi states (districts)
 *
 * @author      WooThemes
 * @category    i18n
 * @package     WooCommerce/i18n
 * @version     2.0.0
 */
global $states;

$states['BD'] = array(
	'BAG'  => __( 'Bagerhat', 'woocommerce' ),
	'BAN'  => __( 'Bandarban', 'woocommerce' ),
	'BAR'  => __( 'Barguna', 'woocommerce' ),
	'BARI' => __( 'Barisal', 'woocommerce' ),
	'BHO'  => __( 'Bhola', 'woocommerce' ),
	'BOG'  => __( 'Bogra', 'woocommerce' ),
	'BRA'  => __( 'Brahmanbaria', 'woocommerce' ),
	'CHA'  => __( 'Chandpur', 'woocommerce' ),
	'CHI'  => __( 'Chittagong', 'woocommerce' ),
	'CHU'  => __( 'Chuadanga', 'woocommerce' ),
	'COM'  => __( 'Comilla', 'woocommerce' ),
	'COX'  => __( 'Cox\'s Bazar', 'woocommerce' ),
	'DHA'  => __( 'Dhaka', 'woocommerce' ),
	'DIN'  => __( 'Dinajpur', 'woocommerce' ),
	'FAR'  => __( 'Faridpur ', 'woocommerce' ),
	'FEN'  => __( 'Feni', 'woocommerce' ),
	'GAI'  => __( 'Gaibandha', 'woocommerce' ),
	'GAZI' => __( 'Gazipur', 'woocommerce' ),
	'GOP'  => __( 'Gopalganj', 'woocommerce' ),
	'HAB'  => __( 'Habiganj', 'woocommerce' ),
	'JAM'  => __( 'Jamalpur', 'woocommerce' ),
	'JES'  => __( 'Jessore', 'woocommerce' ),
	'JHA'  => __( 'Jhalokati', 'woocommerce' ),
	'JHE'  => __( 'Jhenaidah', 'woocommerce' ),
	'JOY'  => __( 'Joypurhat', 'woocommerce' ),
	'KHA'  => __( 'Khagrachhari', 'woocommerce' ),
	'KHU'  => __( 'Khulna', 'woocommerce' ),
	'KIS'  => __( 'Kishoreganj', 'woocommerce' ),
	'KUR'  => __( 'Kurigram', 'woocommerce' ),
	'KUS'  => __( 'Kushtia', 'woocommerce' ),
	'LAK'  => __( 'Lakshmipur', 'woocommerce' ),
	'LAL'  => __( 'Lalmonirhat', 'woocommerce' ),
	'MAD'  => __( 'Madaripur', 'woocommerce' ),
	'MAG'  => __( 'Magura', 'woocommerce' ),
	'MAN'  => __( 'Manikganj ', 'woocommerce' ),
	'MEH'  => __( 'Meherpur', 'woocommerce' ),
	'MOU'  => __( 'Moulvibazar', 'woocommerce' ),
	'MUN'  => __( 'Munshiganj', 'woocommerce' ),
	'MYM'  => __( 'Mymensingh', 'woocommerce' ),
	'NAO'  => __( 'Naogaon', 'woocommerce' ),
	'NAR'  => __( 'Narail', 'woocommerce' ),
	'NARG' => __( 'Narayanganj', 'woocommerce' ),
	'NARD' => __( 'Narsingdi', 'woocommerce' ),
	'NAT'  => __( 'Natore', 'woocommerce' ),
	'NAW'  => __( 'Nawabganj', 'woocommerce' ),
	'NET'  => __( 'Netrakona', 'woocommerce' ),
	'NIL'  => __( 'Nilphamari', 'woocommerce' ),
	'NOA'  => __( 'Noakhali', 'woocommerce' ),
	'PAB'  => __( 'Pabna', 'woocommerce' ),
	'PAN'  => __( 'Panchagarh', 'woocommerce' ),
	'PAT'  => __( 'Patuakhali', 'woocommerce' ),
	'PIR'  => __( 'Pirojpur', 'woocommerce' ),
	'RAJB' => __( 'Rajbari', 'woocommerce' ),
	'RAJ'  => __( 'Rajshahi', 'woocommerce' ),
	'RAN'  => __( 'Rangamati', 'woocommerce' ),
	'RANP' => __( 'Rangpur', 'woocommerce' ),
	'SAT'  => __( 'Satkhira', 'woocommerce' ),
	'SHA'  => __( 'Shariatpur', 'woocommerce' ),
	'SHE'  => __( 'Sherpur', 'woocommerce' ),
	'SIR'  => __( 'Sirajganj', 'woocommerce' ),
	'SUN'  => __( 'Sunamganj', 'woocommerce' ),
	'SYL'  => __( 'Sylhet', 'woocommerce' ),
	'TAN'  => __( 'Tangail', 'woocommerce' ),
	'THA'  => __( 'Thakurgaon', 'woocommerce' )
);
