<?php
/**
 * Indonesia Provinces
 *
 * @author      WooThemes
 * @category    i18n
 * @package     WooCommerce/i18n
 * @version     2.0.0
 */
global $states;

$states['ID'] = array(
	'AC' => __( 'Daerah Istimewa Aceh', 'woocommerce' ),
	'SU' => __( 'Sumatera Utara', 'woocommerce' ),
	'SB' => __( 'Sumatera Barat', 'woocommerce' ),
	'RI' => __( 'Riau', 'woocommerce' ),
	'KR' => __( 'Kepulauan Riau', 'woocommerce' ),
	'JA' => __( 'Jambi', 'woocommerce' ),
	'SS' => __( 'Sumatera Selatan', 'woocommerce' ),
	'BB' => __( 'Bangka Belitung', 'woocommerce' ),
	'BE' => __( 'Bengkulu', 'woocommerce' ),
	'LA' => __( 'Lampung', 'woocommerce' ),
	'JK' => __( 'DKI Jakarta', 'woocommerce' ),
	'JB' => __( 'Jawa Barat', 'woocommerce' ),
	'BT' => __( 'Banten', 'woocommerce' ),
	'JT' => __( 'Jawa Tengah', 'woocommerce' ),
	'JI' => __( 'Jawa Timur', 'woocommerce' ),
	'YO' => __( 'Daerah Istimewa Yogyakarta', 'woocommerce' ),
	'BA' => __( 'Bali', 'woocommerce' ),
	'NB' => __( 'Nusa Tenggara Barat', 'woocommerce' ),
	'NT' => __( 'Nusa Tenggara Timur', 'woocommerce' ),
	'KB' => __( 'Kalimantan Barat', 'woocommerce' ),
	'KT' => __( 'Kalimantan Tengah', 'woocommerce' ),
	'KI' => __( 'Kalimantan Timur', 'woocommerce' ),
	'KS' => __( 'Kalimantan Selatan', 'woocommerce' ),
	'KU' => __( 'Kalimantan Utara', 'woocommerce' ),
	'SA' => __( 'Sulawesi Utara', 'woocommerce' ),
	'ST' => __( 'Sulawesi Tengah', 'woocommerce' ),
	'SG' => __( 'Sulawesi Tenggara', 'woocommerce' ),
	'SR' => __( 'Sulawesi Barat', 'woocommerce' ),
	'SN' => __( 'Sulawesi Selatan', 'woocommerce' ),
	'GO' => __( 'Gorontalo', 'woocommerce' ),
	'MA' => __( 'Maluku', 'woocommerce' ),
	'MU' => __( 'Maluku Utara', 'woocommerce' ),
	'PA' => __( 'Papua', 'woocommerce' ),
	'PB' => __( 'Papua Barat', 'woocommerce' )
);
