/*
Press This TinyMCE editor styles :)
*/


/**
* Links
*/
@import url("//fonts.googleapis.com/css?family=Open+Sans:400italic,700italic,400,600,700");
a {
	color: #0073aa;
}

a:visited {
	color: #0073aa;
}

a:hover,
a:focus,
a:active {
	color: #00a0d2;
}


/**
* Lists
*/
ul,
ol {
	margin: 0 3em 1.5em 0;
}

ul {
	list-style: disc;
}

ol {
	list-style: decimal;
}

li > ul,
li > ol {
	margin-bottom: 0;
	margin-right: 1.5em;
}

dt {
	font-weight: 700;
}

dd {
	margin: 0 1.5em 1.5em;
}


/**
* Media
*
* Basic image and object styles
*/
img {
	max-width: 100%;
	height: auto;
}

/* Makes sure embeds and iframes fit inside their containers */
embed,
iframe,
object {
	max-width: 100%;
}


/**
* TinyMCE styles
*
* Pretty dang good.
*/
body {
	color: #404040;
	font-family: "Open Sans", Helvetica, Arial, sans-serif;
	font-size: 20px;
	font-weight: 400;
	line-height: 1.6;
}
@media (max-width: 900px) {
	body#tinymce {
		padding-top: 30px !important;
	}
}
@media (max-width: 640px) {
	body {
		font-size: 16px;
	}
}
@media (max-width: 320px) {
	body {
		margin: 0 15px;
	}
}

#tinymce b,
#tinymce strong {
	/* overrides TinyMCE's !important. Woohoo. */
	font-weight: 700 !important;
}

blockquote {
	margin: 1em 1.5em;
	color: #9ea7af;
	font-size: em(25px);
	font-style: italic;
}
@media (max-width: 900px) {
	blockquote {
		margin: 1.5em 1em;
	}
}

ul,
ol {
	margin: 0 .75em 1.5em 0;
}
