<?php
/**
 * Hungary states
 *
 * @author      WooThemes
 * @category    i18n
 * @package     WooCommerce/i18n
 * @version     2.0.0
 */
global $states;

$states['HU'] = array(
	'BK' => __( 'Bács-Kiskun', 'woocommerce' ),
	'BE' => __( 'Békés', 'woocommerce' ),
	'BA' => __( 'Baranya', 'woocommerce' ),
	'BZ' => __( 'Borsod-Abaúj-Zemplén', 'woocommerce' ),
	'BU' => __( 'Budapest', 'woocommerce' ),
	'CS' => __( 'Csongrád', 'woocommerce' ),
	'FE' => __( 'Fejér', 'woocommerce' ),
	'GS' => __( 'Győr-Moson-Sopron', 'woocommerce' ),
	'HB' => __( 'Hajdú-Bihar', 'woocommerce' ),
	'HE' => __( 'Heves', 'woocommerce' ),
	'JN' => __( 'Jász-Nagykun-Szolnok', 'woocommerce' ),
	'KE' => __( 'Komárom-Esztergom', 'woocommerce' ),
	'NO' => __( 'Nógrád', 'woocommerce' ),
	'PE' => __( 'Pest', 'woocommerce' ),
	'SO' => __( 'Somogy', 'woocommerce' ),
	'SZ' => __( 'Szabolcs-Szatmár-Bereg', 'woocommerce' ),
	'TO' => __( 'Tolna', 'woocommerce' ),
	'VA' => __( 'Vas', 'woocommerce' ),
	'VE' => __( 'Veszprém', 'woocommerce' ),
	'ZA' => __( 'Zala', 'woocommerce' )
);
