/* This file was automatically generated on Sep 29 2014 23:28:15 */

ul#adminmenu a.wp-has-current-submenu:after,
ul#adminmenu > li.current > a.current:after {
	border-left-color:#8da94c;
	display: none;
}

.omnisearch-results > li:first-child > h2 {
	text-shadow: none;
}
