/*!
* Do not modify this file directly.  It is compiled Sass code.
* @see: jetpack/_inc/jetpack.scss
*/
.j-row {
  width: 100%;
  margin: 0 auto;
}
.j-row:before, .j-row:after {
  content: " ";
  display: table;
}
.j-row:after {
  clear: both;
}

.j-col {
  padding: 0.85em;
  width: 100%;
  float: right;
  position: relative;
}

@media only screen {
  .j-sm-1 {
    width: 8.33333%;
  }

  .j-sm-2 {
    width: 16.66667%;
  }

  .j-sm-3 {
    width: 25%;
  }

  .j-sm-4 {
    width: 33.33333%;
  }

  .j-sm-5 {
    width: 41.66667%;
  }

  .j-sm-6 {
    width: 50%;
  }

  .j-sm-7 {
    width: 58.33333%;
  }

  .j-sm-8 {
    width: 66.66667%;
  }

  .j-sm-9 {
    width: 75%;
  }

  .j-sm-10 {
    width: 83.33333%;
  }

  .j-sm-11 {
    width: 91.66667%;
  }

  .j-sm-12 {
    width: 100%;
  }
}
@media (min-width: 530px) {
  .j-md-1 {
    width: 8.33333%;
  }

  .j-md-2 {
    width: 16.66667%;
  }

  .j-md-3 {
    width: 25%;
  }

  .j-md-4 {
    width: 33.33333%;
  }

  .j-md-5 {
    width: 41.66667%;
  }

  .j-md-6 {
    width: 50%;
  }

  .j-md-7 {
    width: 58.33333%;
  }

  .j-md-8 {
    width: 66.66667%;
  }

  .j-md-9 {
    width: 75%;
  }

  .j-md-10 {
    width: 83.33333%;
  }

  .j-md-11 {
    width: 91.66667%;
  }

  .j-md-12 {
    width: 100%;
  }
}
@media (min-width: 782px) {
  .j-lrg-1 {
    width: 8.33333%;
  }

  .j-lrg-2 {
    width: 16.66667%;
  }

  .j-lrg-3 {
    width: 25%;
  }

  .j-lrg-4 {
    width: 33.33333%;
  }

  .j-lrg-5 {
    width: 41.66667%;
  }

  .j-lrg-6 {
    width: 50%;
  }

  .j-lrg-7 {
    width: 58.33333%;
  }

  .j-lrg-8 {
    width: 66.66667%;
  }

  .j-lrg-9 {
    width: 75%;
  }

  .j-lrg-10 {
    width: 83.33333%;
  }

  .j-lrg-11 {
    width: 91.66667%;
  }

  .j-lrg-12 {
    width: 100%;
  }
}
body,
button,
input,
select,
textarea {
  color: #222;
  font-family: "Open Sans", Helvetica, Arial, sans-serif;
  font-size: 14px;
  line-height: 1.4;
  -webkit-font-smoothing: antialiased;
}

h1,
h2,
h3,
h4,
h5,
h6 {
  color: #222;
  clear: both;
}

a {
  color: #0d72b2;
  transition: color .2s;
  text-decoration: none;
}
a:visited {
  color: #0d72b2;
}
a:hover {
  color: #0f92e5;
}
a:focus {
  outline: thin dotted;
}

address {
  margin: 0 0 1.5em;
}

abbr[title],
acronym {
  cursor: help;
}

ins {
  background: #eee;
  text-decoration: none;
}

dt {
  font-weight: 700;
}

fieldset {
  border: 0;
  margin: 0;
  padding: 0;
}

textarea {
  resize: vertical;
}

hr {
  display: block;
  height: 1px;
  border: 0;
  border-top: 1px solid #ccc;
  margin: 1em 0;
  padding: 0;
}

img {
  vertical-align: middle;
}

@-webkit-keyframes "grow" {
  0% {
    -webkit-transform: scale(0.3);
    transform: scale(0.3);
  }
  60% {
    -webkit-transform: scale(1.15);
    transform: scale(1.15);
  }
  100% {
    -webkit-transform: scale(1);
    transform: scale(1);
  }
}

@keyframes "grow" {
  0% {
    -webkit-transform: scale(0.3);
    transform: scale(0.3);
  }
  60% {
    -webkit-transform: scale(1.15);
    transform: scale(1.15);
  }
  100% {
    -webkit-transform: scale(1);
    transform: scale(1);
  }
}
@-webkit-keyframes "candy" {
  0% {
    -webkit-transform: scale(1);
    transform: scale(1);
  }
  20% {
    -webkit-transform: scale(1.15);
    transform: scale(1.15);
  }
  60% {
    -webkit-transform: scale(0.95);
    transform: scale(0.95);
  }
  100% {
    -webkit-transform: scale(1);
    transform: scale(1);
  }
}
@keyframes "candy" {
  0% {
    -webkit-transform: scale(1);
    transform: scale(1);
  }
  20% {
    -webkit-transform: scale(1.15);
    transform: scale(1.15);
  }
  60% {
    -webkit-transform: scale(0.95);
    transform: scale(0.95);
  }
  100% {
    -webkit-transform: scale(1);
    transform: scale(1);
  }
}
@-webkit-keyframes "flyer" {
  0% {
    -webkit-transform: translate3d(0px, 0px, 0px);
    transform: translate3d(0px, 0px, 0px);
  }
  100% {
    -webkit-transform: translate3d(680px, -680px, 0px);
    transform: translate3d(680px, -680px, 0px);
  }
}
@keyframes "flyer" {
  0% {
    -webkit-transform: translate3d(0px, 0px, 0px);
    transform: translate3d(0px, 0px, 0px);
  }
  100% {
    -webkit-transform: translate3d(680px, -680px, 0px);
    transform: translate3d(680px, -680px, 0px);
  }
}
.button,
.download-jetpack {
  transition: all .1s ease-in-out;
}

.jp-button, .jp-button--settings {
  display: inline-block;
  position: relative;
  padding: 0.76923em 1.46154em;
  color: #efefef;
  font: 800 0.9285714286em/1 'Open Sans', Helvetica, sans-serif;
  text-shadow: 0 -1px 1px rgba(0, 0, 0, 0.2);
  background: #6f7476;
  border-radius: 3px;
}
.jp-button:visited, .jp-button--settings:visited {
  color: #efefef;
}
.jp-button:hover, .jp-button--settings:hover, .jp-button:focus, .jp-button--settings:focus {
  color: #fff;
  background: #57972d;
}
.jp-button:active, .jp-button--settings:active {
  background: #57972d;
  opacity: 0.8;
}

.jp-button--settings {
  background: #93b45f;
  color: #e8eedf;
}
.jp-button--settings:visited {
  color: #e8eedf;
}
.jp-button--settings:hover, .jp-button--settings:focus {
  background: #9fbd72;
  color: #fff;
}
.jp-button--settings.current {
  background: #3c6621;
  color: #fff;
  box-shadow: inset 0 2px 0 #365A1F, inset 0 1px 3px #3c6621;
}

.download-jetpack {
  display: inline-block;
  position: relative;
  padding: 0.64286em 0.85714em 0.53571em;
  color: #fff;
  font: 400 20px/1 "proxima-nova", 'Open Sans', Helvetica, sans-serif;
  background: #518d2a;
  z-index: 3;
  border-radius: 6px;
  box-shadow: 0 6px 0 #3e6c20, 0 6px 3px rgba(0, 0, 0, 0.4);
}
.download-jetpack:visited {
  color: #fff;
}
.download-jetpack:hover, .download-jetpack:focus {
  color: #fff;
  background: #57972d;
  box-shadow: 0 6px 0 #3e6c20, 0 6px 3px rgba(0, 0, 0, 0.4);
}
.download-jetpack:active {
  top: 6px;
  box-shadow: 0 0px 0 #3e6c20, 0 0 0 rgba(0, 0, 0, 0.4);
}
.download-jetpack:active:after {
  top: -6px;
}
.download-jetpack:before {
  content: '';
  display: inline-block;
  position: relative;
  top: -2px;
  margin-left: 13px;
  width: 30px;
  height: 30px;
  vertical-align: middle;
  background: url("../images/connect-plug.svg") center center no-repeat;
  background-size: 100%;
}
.download-jetpack:after {
  content: '';
  position: absolute;
  top: 0;
  right: 0;
  width: 100%;
  height: 100%;
}
@media (max-width: 1147px) {
  .download-jetpack {
    font-size: 1.28571em;
  }
  .download-jetpack:before {
    top: -1px;
    width: 23px;
    height: 23px;
  }
}
@media (max-width: 900px) {
  .download-jetpack:active {
    top: 0;
  }
}
@media (max-width: 530px) {
  .download-jetpack {
    font-size: 1.21429em;
    font-weight: 600;
  }
  .download-jetpack:before {
    width: 19px;
    height: 19px;
    margin-left: 9px;
  }
}

#searchsubmit {
  display: inline-block;
  border: none;
  position: relative;
  padding: 0.71429em 1.5em;
  color: #efefef;
  font: 800 0.8em/1 'Open Sans', Helvetica, sans-serif;
  text-shadow: 0 -1px 1px rgba(0, 0, 0, 0.2);
  background: #6f7476;
  outline: none;
  border-radius: 3px;
}
#searchsubmit:visited {
  color: #efefef;
}
#searchsubmit:hover, #searchsubmit:focus {
  color: #fff;
  background: #2aa0d5;
}
#searchsubmit:active {
  opacity: 0.7;
}

@font-face {
  font-family: 'automatticons';
  src: url("../_inc/fonts/automatticons/automatticons.eot");
  src: url("../_inc/fonts/automatticons/automatticons.eot?#iefix") format("embedded-opentype"), url("../_inc/fonts/automatticons/automatticons.woff") format("woff"), url("../_inc/fonts/automatticons/automatticons.ttf") format("truetype"), url("../_inc/fonts/automatticons/automatticons.svg#automatticonsregular") format("svg");
  font-weight: normal;
  font-style: normal;
}
@font-face {
  font-family: "jetpack";
  src: url("../_inc/fonts/jetpack/jetpack.eot");
  src: url("../_inc/fonts/jetpack/jetpack.eot?#iefix") format("embedded-opentype"), url("../_inc/fonts/jetpack/jetpack.woff") format("woff"), url("../_inc/fonts/jetpack/jetpack.ttf") format("truetype"), url("../_inc/fonts/jetpack/jetpack.svg#jetpack") format("svg");
  font-weight: normal;
  font-style: normal;
}
@media screen and (-webkit-min-device-pixel-ratio: 0) {
  @font-face {
    font-family: "jetpack";
    src: url("../_inc/fonts/jetpack/jetpack.svg#jetpack") format("svg");
  }
}
.nav-horizontal a {
  display: inline-block;
}
.nav-horizontal li {
  position: relative;
  float: right;
}
.nav-horizontal ul {
  margin: 0;
  padding: 0;
}

*,
*:before,
*:after {
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}

::-moz-selection {
  background: #91bd51;
  color: #fff;
  text-shadow: none;
}

::selection {
  background: #91bd51;
  color: #fff;
  text-shadow: none;
}

#wpbody-content {
  padding-bottom: 0;
}

#wpcontent {
  margin-right: 160px;
  padding: 0;
}

ul#adminmenu a.toplevel_page_jetpack:after {
  border-left-color: #81a844;
}

.folded #wpcontent {
  margin-right: 36px;
}

#wpfooter {
  display: none;
}

.jp-content {
  background: #f9f9f9;
  margin: 0;
  height: auto;
  min-height: 100%;
  width: 100%;
  width: 100%;
  -webkit-font-smoothing: antialiased;
}
.jp-content .wrapper {
  background: #f9f9f9;
}

@media (max-width: 900px) {
  #wpcontent,
  .auto-fold #wpcontent,
  .auto-fold #wpfooter,
  .modal,
  .configure .frame.top.fixed {
    margin-right: 36px;
    padding-right: 0;
  }
}
@media (max-width: 782px) {
  #wpcontent,
  .auto-fold #wpcontent,
  .auto-fold #wpfooter,
  .modal,
  .configure .frame.top.fixed {
    margin-right: 0;
  }
}

@media (max-width: 782px) {
  .configure .frame.top.fixed {
    padding-right: 0;
  }
}

.wrap.inner,
.page-content {
  max-width: 950px;
  margin: 0 auto;
}
.wrap.inner li,
.page-content li {
  line-height: 23px;
}

@media (max-width: 530px) {
  .page-content {
    margin-top: 0;
  }
}

@media (max-width: 1147px) {
  .wrap.inner {
    background: #f9f9f9;
    padding: 15px;
  }
}
@media (max-width: 530px) {
  .wrap.inner {
    margin-top: 1.71429em;
  }
}

.jetpack_page_jetpack_modules .header-nav {
  margin: 0;
}
.jetpack_page_jetpack_modules .page-content {
  max-width: 1200px;
  min-height: 500px;
  margin: 0;
}

.page-content.about {
  position: relative;
  z-index: 10;
}
@media (max-width: 1147px) {
  .page-content.about {
    background: #f9f9f9;
    padding: 15px;
  }
}

@media (max-width: 1147px) {
  .page-content.configure {
    background: #f9f9f9;
  }
}

.footer nav {
  max-width: 550px;
  margin: 0 auto;
}

.header {
  right: 0;
  left: 0;
  background: #81a844;
}

.header-nav li {
  line-height: 60px;
}
.header-nav a {
  padding: 0 0.71429em;
  line-height: 24px;
}
.header-nav .jetpack-logo a {
  display: inline-block;
  position: relative;
  width: 214px;
  margin-left: 6px;
  background: url(../images/jetpack-logo.png) center center no-repeat;
  background: url(../images/jetpack-logo.svg) center center no-repeat, none;
  background-size: 183px auto;
  color: #fff;
  line-height: 60px;
  font-weight: normal;
}
.header-nav .jetpack-logo a span {
  text-indent: -9999px;
  visibility: hidden;
}
.header-nav .jetpack-logo a:before {
  content: '';
  position: absolute;
  top: 0;
  right: 0;
  width: 100%;
  height: 100%;
  background-size: 183px 32px;
}
.header-nav .jetpack-modules + .jetpack-modules {
  margin-right: 15px;
}

.main-nav {
  float: right;
}
.main-nav li {
  margin: 0;
}
@media (max-width: 900px) {
  .main-nav {
    font-size: 13px;
  }
}

.user-nav {
  float: left;
}
.user-nav li {
  margin: 0;
}

.jetpack-pagestyles #screen-meta {
  margin: 0;
}
.jetpack-pagestyles #screen-meta-links .screen-meta-toggle {
  z-index: 2;
}
.jetpack-pagestyles #screen-options-link-wrap, .jetpack-pagestyles #contextual-help-link-wrap {
  border: none;
}
.jetpack-pagestyles .update-nag {
  display: none;
}

.masthead {
  position: relative;
  text-align: center;
  z-index: 1;
  background-color: #81a844;
  background-image: linear-gradient(top, #81a844, #8eb74e);
}
.masthead.hasbutton .flyer {
  bottom: -270px;
}
.masthead.hasbutton .subhead {
  margin-top: 175px;
}
@media (max-width: 530px) {
  .masthead.hasbutton .subhead {
    margin-top: 105px;
    padding: 0;
  }
}
.masthead h1,
.masthead h2 {
  margin: 0 auto;
}
.masthead h1 {
  padding: 2.5em 0 1.11111em;
  max-width: 21.94444em;
  color: #fff;
  font: 300 2.57143em/1.4em "proxima-nova", "Open Sans", Helvetica, Arial, sans-serif;
  position: relative;
  text-shadow: 0 -1px 1px rgba(0, 0, 0, 0.12);
  z-index: 3;
}
.masthead h1 + .flyby {
  margin-top: 180px;
}
@media (max-width: 1147px) {
  .masthead h1 {
    padding-top: 1.83333em;
    font-size: 2.14286em;
  }
}
@media (max-width: 782px) {
  .masthead h1 {
    max-width: 600px;
    font-size: 28px;
  }
}
@media (max-width: 530px) {
  .masthead h1 {
    margin: 0 15px;
    padding: 31px 0 15px 0;
    font-size: 21px;
    font-weight: 400;
  }
}

.jetpack-connected .masthead h1 {
  margin-bottom: 33px;
  max-width: 600px;
}

.flyby {
  position: relative;
  max-width: 1200px;
  margin: 0 auto;
}
@media (max-width: 900px) {
  .flyby {
    display: none;
  }
}

.flyer {
  position: absolute;
  bottom: -200px;
  right: 4%;
  z-index: 1;
  -webkit-animation: flyer 3.4s 2s ease-in-out;
  animation: flyer 3.4s 2s ease-in-out;
}
.flyer:nth-child(2) {
  right: 49%;
  width: 120px;
  height: 131px;
  -webkit-animation-delay: 4.6s;
  animation-delay: 4.6s;
  -webkit-animation-duration: 2.4s;
  animation-duration: 2.4s;
}
.flyer:nth-child(3) {
  right: 23%;
  width: 60px;
  height: 66px;
  -webkit-animation-delay: 5.8s;
  animation-delay: 5.8s;
  -webkit-animation-duration: 4.5s;
  animation-duration: 4.5s;
}

.subhead {
  position: relative;
  margin-top: 105px;
  padding: 4em 0;
  background: #f9f9f9;
  z-index: 2;
}
.subhead h2 {
  max-width: 460px;
  color: #5d6d74;
  font: 400 1.57143em/1.4em "proxima-nova", "Open Sans", Helvetica, Arial, sans-serif;
  text-shadow: 0 -1px 1px #fff;
}
@media (max-width: 900px) {
  .subhead h2 {
    max-width: 428px;
    font-size: 20px;
  }
}
@media (max-width: 530px) {
  .subhead h2 {
    display: none;
  }
}
.subhead:after {
  content: '';
  position: absolute;
  bottom: 100%;
  right: 0;
  margin-bottom: -1px;
  width: 100%;
  height: 228px;
  background: url("../images/the-cloud.svg") center bottom repeat-x;
  pointer-events: none;
  z-index: -1;
}
@media (max-width: 1147px) {
  .subhead {
    margin-top: 122px;
    padding: 70px 0 49px;
  }
  .subhead:after {
    background-size: 160% auto;
  }
}
@media (max-width: 900px) {
  .subhead {
    margin-top: 122px;
    padding: 70px 0 49px;
  }
}
@media (max-width: 530px) {
  .subhead {
    margin-top: 83px;
    padding: 47px 15px 39px;
  }
}

.clouds-sm {
  height: 100px;
  position: relative;
  text-align: center;
  z-index: 1;
  background-color: #81a844;
  background-image: linear-gradient(top, #81a844, #89b348);
}
.clouds-sm:after {
  content: '';
  position: absolute;
  bottom: 0;
  right: 0;
  margin-bottom: -1px;
  width: 100%;
  height: 137px;
  background: url("../images/the-cloud-sm.svg") center bottom repeat-x;
  pointer-events: none;
  z-index: 2;
}
@media (max-width: 530px) {
  .clouds-sm {
    height: 90px;
  }
}

.featured {
  border-top: 1px solid #d6d6d6;
  border-bottom: 1px solid #d6d6d6;
  background: #fff;
  position: relative;
  padding: 2.0em 1em 4.6em 1em;
  text-align: center;
  z-index: 1;
}
.featured:before {
  content: "";
  display: block;
  position: absolute;
  top: 0;
  height: 100%;
  z-index: -1;
}
.featured .features, .featured .modules {
  margin: 0 auto;
  display: inline-block;
}
@media (max-width: 530px) {
  .featured {
    display: none;
  }
}

.featured h2,
.module-grid h2 {
  margin-top: 1em;
  color: #5d6d74;
  font: 300 2em/1em "proxima-nova", "Open Sans", Helvetica, Arial, sans-serif;
  text-align: center;
}
@media (max-width: 900px) {
  .featured h2,
  .module-grid h2 {
    font-size: 30px;
  }
}
@media (max-width: 782px) {
  .featured h2,
  .module-grid h2 {
    font-size: 28px;
  }
}

.features, .modules {
  margin: 0 -5px;
}

.feature,
.module {
  position: relative;
  float: right;
  margin: 0 5px 10px;
  width: 310px;
  transition: all .2s ease-in-out;
}
@media (max-width: 1147px) {
  .feature,
  .module {
    margin: .75% 1.5% .75% 0;
    width: 32.333333%;
    transition: none;
  }
  .feature:nth-child(3n + 1),
  .module:nth-child(3n + 1) {
    margin-right: 0;
  }
  .feature:hover,
  .module:hover {
    top: 0;
    box-shadow: none;
  }
}

.feature {
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
}
.feature h3 {
  margin: 0 0 0.58824em;
  color: #697b84;
  font-size: 1.21429em;
  line-height: 1em;
  font-weight: 800;
}
.feature p {
  margin: 0;
  color: #6e818a;
}
.feature:before {
  content: '';
  position: absolute;
  bottom: 0;
  right: 0;
  width: 100%;
  height: 10px;
  background: rgba(0, 0, 0, 0.02);
  z-index: -1;
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
  transition: all .2s ease-in-out;
}
.feature:hover {
  -webkit-transform: translateY(-5px);
  -ms-transform: translateY(-5px);
  transform: translateY(-5px);
}
.feature:hover h3 {
  color: #1a8dba;
}
.feature:hover .feature-img {
  border: 1px solid #ccc;
  border-bottom: none;
}
.feature:hover .no-border {
  border: none;
}
.feature:hover:before {
  -webkit-transform: translateY(5px);
  -ms-transform: translateY(5px);
  transform: translateY(5px);
}
@media (max-width: 1147px) {
  .feature:hover h3 {
    color: #6e818a;
  }
  .feature:hover .feature-img {
    border: 1px solid #ddd;
    border-bottom: none;
  }
  .feature:hover .no-border {
    border: none;
  }
}
.feature .feature-img {
  padding-top: 52%;
  width: 100%;
  height: auto;
  border: 1px solid #ddd;
  border-bottom: none;
}
.feature .feature-img.custom-css {
  background: url("../images/custom-css.jpg") no-repeat;
  background-size: 100% auto;
}
@media print, (-webkit-min-device-pixel-ratio: 1.25), (min--moz-device-pixel-ratio: 1.25), (-o-min-device-pixel-ratio: 5 / 4), (min-resolution: 120dpi) {
  .feature .feature-img.custom-css {
    background-image: url("../images/custom-css@2x.jpg");
  }
}
.feature .feature-img.wordpress-connect {
  background: url("../images/wordpress-connect.jpg") no-repeat;
  background-size: 100% auto;
}
@media print, (-webkit-min-device-pixel-ratio: 1.25), (min--moz-device-pixel-ratio: 1.25), (-o-min-device-pixel-ratio: 5 / 4), (min-resolution: 120dpi) {
  .feature .feature-img.wordpress-connect {
    background-image: url("../images/wordpress-connect@2x.jpg");
  }
}
.feature .feature-img.wordpress-stats {
  background: url("../images/wordpress-stats.jpg") no-repeat;
  background-size: 100% auto;
}
@media print, (-webkit-min-device-pixel-ratio: 1.25), (min--moz-device-pixel-ratio: 1.25), (-o-min-device-pixel-ratio: 5 / 4), (min-resolution: 120dpi) {
  .feature .feature-img.wordpress-stats {
    background-image: url("../images/wordpress-stats@2x.jpg");
  }
}
.feature .feature-img.no-border {
  border: none;
  padding-bottom: 1px;
}

.feature-description {
  display: block;
  padding: 1em 1.07143em 1.07143em;
  border: 1px solid #ddd;
  background: #f5f5f5;
}
.feature:hover .feature-description {
  background: #fff;
  border-color: #ccc;
}
@media (max-width: 1147px) {
  .feature:hover .feature-description {
    border: 1px solid #ddd;
    background: #f5f5f5;
  }
}
@media (max-width: 900px) {
  .feature-description {
    min-height: 115px;
  }
}

.cat {
  clear: both;
  margin-bottom: 23px;
}
.cat h3 {
  font-size: 24px;
  font-weight: 300;
  margin: 0 6px 13px 0;
  text-align: right;
}
.cat .clear {
  clear: both;
}

.module-grid {
  text-align: center;
}
.module-grid h2 {
  margin: 1em 0;
}
@media (max-width: 530px) {
  .module-grid h2 {
    padding-top: 16px;
    margin-top: 0;
    font-size: 25px;
  }
}

#module-search {
  position: relative;
  width: 100%;
  max-width: 40.71429em;
  margin: 0 auto 1.07143em;
  overflow: hidden;
}

#jetpack-search {
  margin: 0;
  padding: 11px 16px 11px 16px;
  width: 100%;
  border: 1px solid #c9ced0;
  border-radius: 3px;
  background: #fff;
  color: #5c6671;
  line-height: 1.3;
}
#jetpack-search:focus {
  color: #5c6671;
  outline: none;
}
#jetpack-search:focus + label {
  background: transparent;
  opacity: 0;
}
#jetpack-search::-webkit-input-placeholder {
  color: #a8acae;
}
#jetpack-search :-moz-placeholder {
  color: #a8acae;
}
#jetpack-search::-moz-placeholder {
  color: #a8acae;
}
#jetpack-search:-ms-input-placeholder {
  color: #a8acae;
}
#jetpack-search + label {
  position: absolute;
  top: 1px;
  left: 1px;
  bottom: 1px;
  width: 48px;
  color: #abafb1;
  text-indent: -9999px;
  pointer-events: none;
  border-radius: 3px;
  transition: all .2s ease-in-out;
}
#jetpack-search + label:after {
  content: '\f400';
  position: absolute;
  left: 11px;
  text-align: left;
  top: 4px;
  font-size: 1.71429em;
  font-weight: normal;
  font-family: "genericons";
}

.jp-filter {
  margin-bottom: 2.85714em;
  color: #6f7476;
}
.jp-filter a {
  display: inline-block;
  position: relative;
  padding: 0.76923em 1.46154em;
  color: #aaa;
  font: 600 0.92857em/1 "Open Sans", Helvetica, Arial, sans-serif;
  text-shadow: 0 -1px 1px rgba(255, 255, 255, 0.2);
  background: #eee;
  border-radius: 3px;
  background-clip: padding-box;
}
.jp-filter a.selected, .jp-filter a:hover, .jp-filter a:focus {
  color: #efefef;
  text-shadow: 0 -1px 1px rgba(0, 0, 0, 0.2);
  background: #6f7476;
}
@media (max-width: 530px) {
  .jp-filter a {
    padding: 0.76em 1em;
  }
}

.module {
  display: block;
  padding: 0.71429em 1.07143em 1em;
  text-align: right;
  border: 1px solid #dae0e2;
  background: #fff;
  box-shadow: 0 0 0 rgba(0, 0, 0, 0.03);
  transition: opacity 2s ease-in;
}
.module:hover {
  border-color: #8ac9e8;
  background: #f8fcfe;
}
.module h3 {
  cursor: pointer;
  margin: 0 0 0.5em;
  color: #1a8dba;
  font-size: 1.14286em;
  line-height: 1.4em;
  font-weight: 700;
}
.module p {
  margin: 0;
  color: #686f72;
  font-size: 0.85714em;
}
.module:hover, .module:focus {
  border-color: #8ac9e8;
  background: #f8fcfe;
}
.module.active {
  border-color: #2ea2cc;
  box-shadow: inset -4px 0 0 #2ea2cc;
}
.module.active:hover {
  border-color: #69bedd;
  box-shadow: inset -4px 0 0 #69bedd;
}
@media (max-width: 1147px) {
  .cat .module:nth-child(3n + 1) {
    margin: .75% 1.5% .75% 0;
  }
  .cat .module:nth-child(3n - 1) {
    margin-right: 0;
  }
}
@media (max-width: 900px) {
  .cat .module {
    margin: 1% 2% 1% 0;
  }
  .cat .module:nth-child(2n + 1) {
    margin: 1% 2% 1% 0;
  }
  .cat .module:nth-child(2n + 0) {
    margin-right: 0;
  }
}
@media (max-width: 530px) {
  .cat .module {
    margin: 5px 0;
  }
  .cat .module:nth-child(2n + 1) {
    margin-right: 0;
  }
  .cat .module:nth-child(2n + 0) {
    margin-right: 0;
  }
}
@media (max-width: 900px) {
  .module {
    margin: 1% 2% 1% 0;
    width: 49%;
  }
  .module:nth-child(3n + 1) {
    margin-right: 2%;
  }
  .module:nth-child(2n + 1) {
    margin-right: 0;
  }
}
@media (max-width: 530px) {
  .module {
    margin: 5px 0;
    width: 100%;
  }
  .module:nth-child(3n + 1) {
    margin-right: 0;
  }
  .module:nth-child(2n + 1) {
    margin-right: 0;
  }
}

.new {
  position: relative;
}
.new:after {
  content: 'NEW';
  position: absolute;
  top: -8px;
  left: -8px;
  padding-top: 10px;
  width: 32px;
  height: 32px;
  color: #fff;
  font-size: 8px;
  font-weight: 800;
  text-align: center;
  text-shadow: 0 1px 0 rgba(0, 0, 0, 0.2);
  background: url("../images/new-badge.svg") center center no-repeat;
  background-size: 100%;
  border-radius: 50%;
}

.paid {
  display: inline-block;
  position: relative;
  top: 5px;
  margin-right: 10px;
  padding: 1px 4px 0 6px;
  height: 13px;
  color: #fff;
  font: 700 10px/1 "Open Sans", Helvetica, Arial, sans-serif;
  text-shadow: 0 1px 0 rgba(0, 0, 0, 0.05);
  background: #d0d0d0;
  vertical-align: top;
}
.paid:before, .paid:after {
  position: absolute;
  top: 0;
  left: 100%;
  font: normal 14px/14px "genericons";
}
.paid:before {
  content: '\f503';
  color: #d0d0d0;
  text-shadow: none;
}
.paid:after {
  content: '\f428';
  margin-left: -5px;
  font-size: 11px;
}

.rtl .paid:before {
  content: '\f501';
}

.load-more {
  margin: 2.71429em 0 6.15385em;
}

.set {
  display: none;
}

.show.set {
  display: block;
}

.loading {
  bottom: 50%;
  position: absolute;
  top: 50%;
  width: 100%;
}
.loading span {
  color: #999;
}

.modal {
  background: #fff;
  position: fixed;
  top: 52px;
  bottom: 20px;
  left: 20px;
  right: 20px;
  margin-right: 160px;
  display: none;
  box-shadow: 0 1px 20px 5px rgba(0, 0, 0, 0.1);
  z-index: 500;
}
.modal .close {
  position: absolute;
  top: 0;
  left: 0;
  font: 300 1.71429em "genericons" !important;
  color: #777;
  content: '\f405';
  display: inline-block;
  padding: 0.28571em 0.71429em 0.42857em;
  z-index: 5;
}
.modal .close:hover {
  background: #eee;
  opacity: 0.8;
}
.modal .close:active {
  background: #eee;
  opacity: 0.4;
}
.modal #jp-post-flair {
  display: none;
}
.modal .content-container {
  position: absolute;
  top: 0;
  left: 0;
  bottom: 0;
  right: 0;
  overflow: auto;
  padding: 2.14286em;
}
.modal .content {
  margin: 0 auto;
  max-width: 900px;
  text-align: right;
}
.modal h2 {
  text-align: right;
  margin-top: 0;
  color: #5d6d74;
  font: 300 32px "proxima-nova", "Open Sans", Helvetica, Arial, sans-serif;
  text-shadow: 0 -1px 1px #fff;
}
@media (max-width: 530px) {
  .modal h2 {
    font-size: 26px;
  }
}
.modal h5 {
  clear: right;
}
.modal p {
  font-size: 1.23077em;
}
.modal footer {
  position: absolute;
  right: 0;
  bottom: 0;
  width: 100%;
  padding: 12px 20px;
  border-top: 1px solid #ddd;
  background: #fff;
  text-align: left;
}
.modal footer ul {
  margin: 0;
}
.modal footer li {
  display: inline-block;
  margin: 0;
}
.modal .button-secondary,
.modal .button-primary:active {
  vertical-align: baseline;
}
@media (max-width: 900px) {
  .modal {
    bottom: 5%;
    margin-right: 36px;
    font-size: 80%;
  }
  .modal .content {
    top: 38px;
  }
}
@media (max-width: 782px) {
  .modal {
    top: 66px;
    margin-right: 0;
  }
}
@media (max-width: 600px) {
  .modal {
    top: 10px;
    left: 10px;
    bottom: 10px;
    right: 10px;
  }
}

.jp-info-img {
  float: left;
  margin: 0 30px 30px 0;
}
.jp-info-img img {
  border: 1px solid #ddd;
  max-width: 100%;
  height: auto;
}
.jp-info-img img:first-child {
  margin-top: 0;
}
@media (max-width: 782px) {
  .jp-info-img {
    float: none;
    margin: 0 0 15px;
  }
}

.content-container.modal-footer {
  bottom: 53px;
}

.shade {
  background: #000;
  bottom: 0;
  cursor: pointer;
  display: none;
  right: 0;
  opacity: 0.2;
  position: fixed;
  left: 0;
  top: 0;
  z-index: 11;
}

.entry-title,
.page-template-default h1 {
  margin-top: 0.61111em;
  color: #5d6d74;
  font: 300 2.57143em/1.4em "proxima-nova", "Open Sans", Helvetica, Arial, sans-serif;
  text-shadow: 0 -1px 1px #fff;
}
@media (max-width: 530px) {
  .entry-title,
  .page-template-default h1 {
    font-size: 2em;
  }
}

.blog h3,
.single h3,
.page-template-default h2 {
  margin-top: 0.61111em;
  color: #5d6d74;
  font: 300 1.9em "proxima-nova", "Open Sans", Helvetica, Arial, sans-serif;
  text-shadow: 0 -1px 1px #fff;
}
@media (max-width: 530px) {
  .blog h3,
  .single h3,
  .page-template-default h2 {
    font-size: 1.4em;
  }
}

.page-template-default p {
  line-height: 1.71429em;
}

.blog .type-post,
.page-template-default .type-page,
.single .type-post,
.single .type-jetpack_support {
  float: right;
  width: 70%;
}

.footer {
  margin-top: 1.42857em;
  position: relative;
  padding: 10em 0 4.28571em;
  text-align: center;
}
.footer:before, .footer:after {
  content: '';
  position: absolute;
  right: 0;
  pointer-events: none;
}
.footer:before {
  top: 0;
  margin-top: -1px;
  width: 100%;
  height: 195px;
}
.footer:after {
  bottom: 0;
  width: 100%;
  height: 50px;
  background: url("../images/the-footcloud.svg") center bottom no-repeat;
  background-size: auto 45px;
  z-index: 1;
}
.footer .download-jetpack {
  margin-bottom: 33px;
}
@media (max-width: 1147px) {
  .footer {
    padding-top: 165px;
    padding-bottom: 0;
  }
  .footer:before {
    background-size: 160% auto;
  }
  .footer:after {
    display: none;
  }
  .footer ul {
    float: none;
    overflow: hidden;
  }
}
@media (max-width: 900px) {
  .footer {
    padding-top: 146px;
  }
}
@media (max-width: 782px) {
  .footer {
    margin-top: 0;
  }
}
@media (max-width: 530px) {
  .footer {
    margin-top: 0;
    padding-top: 135px;
  }
}
@media (max-width: 320px) {
  .footer {
    padding-top: 76px;
  }
}

.footer nav {
  max-width: 100%;
}
.footer nav a,
.footer nav a:visited {
  padding: 4px 6px;
  color: #999;
}
.footer nav a:hover, .footer nav a:focus,
.footer nav a:visited:hover,
.footer nav a:visited:focus {
  color: #81A844;
}
@media (max-width: 1147px) {
  .footer nav {
    border: none;
    padding: 0;
  }
  .footer nav a:hover, .footer nav a:focus,
  .footer nav a:visited:hover,
  .footer nav a:visited:focus {
    color: #fff;
  }
}
@media (max-width: 530px) {
  .footer nav li {
    display: block;
    float: none;
    margin: 0;
    text-align: right;
  }
  .footer nav a {
    display: block;
    padding: 0 16px;
    line-height: 44px;
  }
}

.primary {
  padding: 25px 15px 10px 15px;
  border-bottom: 1px solid #eee;
}

.secondary-footer {
  margin: 0 auto;
}
.secondary-footer li {
  margin-left: 5px;
}
@media (max-width: 1147px) {
  .secondary-footer {
    margin: 0 30px;
    padding: 8px 15px 30px;
  }
}
@media (max-width: 530px) {
  .secondary-footer {
    margin: 0;
    padding: 0;
    border: none;
    font-weight: 400;
  }
  .secondary-footer a {
    border-top: 1px solid #eee;
  }
}

.footer .a8c-attribution {
  margin: 0;
  padding: 0 6px;
  color: #bbb;
  font-size: 0.78571em;
  font-family: "Gill Sans", "Gill Sans MT", "Open Sans", Helvetica, Arial, sans-serif;
  text-transform: uppercase;
  /*@include breakpoint(large-desktop){
  	display: none;
  };*/
}
.footer .a8c-attribution a {
  display: inline-block;
  position: relative;
  padding: 4px 16px;
  left: 9999px;
  outline: 0;
}
.footer .a8c-attribution a:after {
  content: 'A';
  position: absolute;
  top: 2px;
  left: -9999px;
  height: 100%;
  color: #999;
  font-size: 1.54545em;
  font-family: "automatticons";
  text-align: center;
}
.footer .a8c-attribution a:hover:after {
  -webkit-animation: candy .4s ease-in-out;
  animation: candy .4s ease-in-out;
}

.secondary {
  padding: 10px 15px 0 15px;
}

.jetpack-message {
  background: #8eb74e;
  border: 1px solid #73963d;
  margin: 33px auto 0;
  max-width: 90%;
  position: relative;
  z-index: 2;
}
.jetpack-message.is-opt-in {
  margin: 50px 0 0;
  max-width: 100%;
  padding: 10px 15px;
  background: #fff;
  border: 0;
  box-shadow: 0 1px 1px 0 rgba(0, 0, 0, 0.1);
  font-size: 13px;
  text-align: center;
}
.subhead .jetpack-message.is-opt-in {
  margin: 0;
  padding-bottom: 0;
  background: transparent;
  box-shadow: none;
}
.subhead .jetpack-message.is-opt-in .jp-button, .subhead .jetpack-message.is-opt-in .jp-button--settings {
  display: inline-block;
}
.jetpack-message.is-opt-in p {
  color: #3c4549;
}
.jetpack-message.is-opt-in .jp-button, .jetpack-message.is-opt-in .jp-button--settings {
  margin-top: 15px;
  display: none;
}
.jetpack-message h4 {
  color: #fff;
  margin: 0;
}
.jetpack-message p {
  color: #fff;
  margin: 0;
  opacity: 0.7;
}
.jetpack-message .squeezer {
  padding: 23px 80px 23px 23px;
  position: relative;
  text-align: right;
}
.jetpack-message .squeezer:before {
  color: #fff;
  content: '\f418';
  font-family: 'Genericons';
  font-size: 33px;
  height: 33px;
  right: 25px;
  opacity: 0.6;
  position: absolute;
  top: 23px;
  top: calc( 50% - 22px );
}
@media (max-width: 530px) {
  .jetpack-message .squeezer {
    padding: 23px;
  }
  .jetpack-message .squeezer:before {
    display: none;
  }
}
.jetpack-message .squeezer a {
  color: #FFF;
  border-bottom: 1px solid #D5E4BD;
}
.jetpack-message .squeezer a:hover {
  border-bottom: 1px solid #F1F6E9;
}
.jetpack-message.error .squeezer:before, .jetpack-message.jetpack-err .squeezer:before {
  content: '\f414';
}

.configure-module .jetpack-message {
  max-width: 100%;
}

.modules h3.icon,
.jetpack-modules .info a {
  width: auto;
}
.modules h3.icon:before,
.jetpack-modules .info a:before {
  display: inline-block;
  position: relative;
  top: 1px;
  right: -3px;
  margin-left: 2px;
  opacity: 0.8;
  font: normal 20px "genericons";
  vertical-align: top;
}

.jetpack-modules .info a:before {
  margin-top: 1px;
}

.latex:before,
.jetpack-modules #latex .info a:before {
  content: '\f408';
}

.carousel:before,
.jetpack-modules #carousel .info a:before {
  content: '\f102';
}

.modules h3.contact-form:before,
.jetpack-modules #contact-form .info a:before {
  content: '\f175';
  font: normal 20px "dashicons";
}

.modules h3.custom-css:before,
.jetpack-modules #custom-css .info a:before {
  content: '\f100';
  font: normal 20px "dashicons";
}

.modules h3.enhanced-distribution:before,
.jetpack-modules #enhanced-distribution .info a:before {
  content: '\f237';
  font: normal 20px "dashicons";
}

.modules h3.widgets:before,
.jetpack-modules #widgets .info a:before {
  content: '\f116';
  font: normal 20px "dashicons";
}

.modules h3.gravatar-hovercards:before,
.jetpack-modules #gravatar-hovercards .info a:before {
  content: 'G';
  font-family: "automatticons";
}

.infinite-scroll:before,
.jetpack-modules #infinite-scroll .info a:before {
  content: '\f408';
}

.comments:before,
.jetpack-modules #comments .info a:before {
  content: '\f108';
}

.sso:before,
.jetpack-modules #sso .info a:before {
  content: '\f205';
}

.json-api:before,
.jetpack-modules #json-api .info a:before {
  content: '\f415';
}

.likes:before,
.jetpack-modules #likes .info a:before {
  content: '\f408';
}

.markdown:before,
.jetpack-modules #markdown .info a:before {
  content: '\f462';
}

.minileven:before,
.jetpack-modules #minileven .info a:before {
  content: '\f453';
}

.manage:before,
.jetpack-modules #manage .info a:before {
  content: '\f205';
}

.monitor:before,
.jetpack-modules #monitor .info a:before {
  content: '\f468';
}

.notes:before,
.jetpack-modules #notes .info a:before {
  content: '\f300';
}

.omnisearch:before,
.jetpack-modules #omnisearch .info a:before {
  content: '\f400';
}

.photon:before,
.jetpack-modules #photon .info a:before {
  content: '\f403';
}

.post-by-email:before,
.jetpack-modules #post-by-email .info a:before {
  content: '\f410';
}

.protect:before,
.jetpack-modules #protect .info a:before {
  content: '\f470';
  position: relative;
  top: -1px;
}

.modules h3.publicize:before,
.jetpack-modules #publicize .info a:before {
  content: '\f237';
  font: normal 20px "dashicons";
}

.related-posts:before,
.jetpack-modules #related-posts .info a:before {
  content: '\f420';
}

.sharedaddy:before,
.jetpack-modules #sharedaddy .info a:before {
  content: '\f415';
}

.shortcodes:before,
.jetpack-modules #shortcodes .info a:before {
  content: '\f100';
}

.verification-tools:before,
.jetpack-modules #verification-tools .info a:before {
  content: '\f425';
}

.after-the-deadline:before,
.jetpack-modules #after-the-deadline .info a:before {
  content: '\f411';
}

.subscriptions:before,
.jetpack-modules #subscriptions .info a:before {
  content: '\f410';
}

.tiled-gallery:before,
.jetpack-modules #tiled-gallery .info a:before {
  content: '\f103';
}

.modules h3.vaultpress:before,
.jetpack-modules #vaultpress .info a:before {
  content: 'V';
  font-family: "automatticons";
}

.videopress:before,
.jetpack-modules #videopress .info a:before {
  content: '\f104';
}

.modules h3.widget-visibility:before,
.jetpack-modules #widget-visibility .info a:before {
  content: '\f116';
  font: normal 20px "dashicons";
}

.stats:before,
.jetpack-modules #stats .info a:before {
  content: '\f205';
}

.shortlinks:before,
.jetpack-modules #shortlinks .info a:before {
  content: '\f107';
}

.modules h3.custom-content-types:before,
.jetpack-modules #custom-content-types .info a:before {
  content: '\f498';
  font: normal 20px "dashicons";
}

.modules h3.site-icon:before,
.jetpack-modules #site-icon .info a:before {
  content: '\f475';
}

@media (max-width: 782px) {
  .blog .type-post,
  .page-template-default .type-page,
  .single .type-post,
  .single .type-jetpack_support {
    width: 100%;
  }
}
@media (max-width: 600px) {
  .clouds-sm {
    display: none;
  }
}
@media (max-width: 530px) {
  .wrap.inner.jp-support .jp-support-column-left {
    width: 100%;
  }
  .wrap.inner.jp-support .jp-support-column-left .widget-text {
    margin-left: 0;
    width: 100%;
  }
  .wrap.inner.jp-support .jp-support-column-right {
    width: 100%;
  }
}
@media screen and (max-width: 400px) {
  .jp-frame .header-nav {
    padding-bottom: 10px;
  }
  .jp-frame .header-nav li {
    line-height: 30px;
  }
  .jp-frame .header-nav .jetpack-logo {
    width: 100%;
    text-align: center;
  }
  .jp-frame .header-nav .jetpack-modules {
    margin: 0;
    width: 50%;
    text-align: left;
    padding: 0 5px;
  }
  .jp-frame .header-nav .jetpack-modules + .jetpack-modules {
    text-align: right;
  }
}
@media (max-width: 320px) {
  .jetpack_page_jetpack_modules .wrap {
    padding: 0 0 1em;
  }
}

.page-content.configure {
  margin-top: 0;
}

.configure .frame.top {
  border: none;
  box-shadow: none;
  padding-top: 1.42857em;
  position: relative;
  top: auto;
}
.configure .frame.top.fixed {
  background: #f9f9f9;
  border-bottom: 1px solid #e9e9e9;
  padding-right: 160px;
  margin-top: -6px;
  position: fixed;
  left: 0;
  top: 32px;
  width: 100%;
  z-index: 4;
  box-shadow: 0 2px 2px -2px #eee;
}
@media (max-width: 782px) {
  .configure .frame.top.fixed {
    border: none;
    box-shadow: none;
    padding-top: 1.42857em;
    position: relative;
    top: auto;
  }
}
@media (max-width: 600px) {
  .configure .frame.top.fixed {
    top: 0;
  }
}
.configure .frame.top .tablenav.top {
  float: right;
}
@media (max-width: 900px) {
  .configure .frame.top .tablenav.top .actions {
    display: block;
  }
}
@media (max-width: 782px) {
  .configure .frame.top .tablenav.top .actions {
    margin-top: 6px;
  }
}

.jp-frame-top-fixed .configure {
  padding-top: 94px;
}

.filter-search {
  display: none;
  float: left;
  margin-top: 10px;
}
@media (max-width: 782px) {
  .filter-search {
    display: block;
  }
}
@media (max-width: 530px) {
  .filter-search {
    display: none;
  }
}

.module-actions.landing-page {
  float: left;
  margin-left: 15px;
}
.module-actions.landing-page a {
  font-size: 0.6em;
}

.table-bordered.jetpack-modules {
  border: none;
  margin-bottom: 0;
}
.table-bordered.jetpack-modules tr.jetpack-module th {
  border-right: 0;
  padding: 14px 4px 0;
}
.table-bordered.jetpack-modules tr.jetpack-module th input {
  display: block;
}
.table-bordered.jetpack-modules tr.jetpack-module:hover .genericon {
  display: inline-block;
}
.table-bordered.jetpack-modules tr.jetpack-module:hover td .row-actions span a {
  opacity: 1;
}
.table-bordered.jetpack-modules tr.jetpack-module.active th,
.table-bordered.jetpack-modules tr.jetpack-module.active td {
  background: #f7fcfe;
}
.table-bordered.jetpack-modules tr.jetpack-module.active th {
  border-right: 4px solid #2ea2cc;
  padding-right: 0px;
}
.table-bordered.jetpack-modules tr.jetpack-module.active td:first-child {
  border-right: 4px solid #2ea2cc;
}
.table-bordered.jetpack-modules tr.jetpack-module.unavailable {
  opacity: 0.3;
}
.table-bordered.jetpack-modules tr.jetpack-module.unavailable input {
  display: none;
}
.table-bordered.jetpack-modules tr.jetpack-module#vaultpress {
  opacity: 1;
}
.table-bordered.jetpack-modules tr.jetpack-module th,
.table-bordered.jetpack-modules tr.jetpack-module td {
  background: #fff;
  margin: 0;
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.1);
}
.table-bordered.jetpack-modules tr.jetpack-module td {
  padding: 10px 14px 8px 10px;
  line-height: 25px;
}
.table-bordered.jetpack-modules tr.jetpack-module td:first-child {
  border-right: 4px solid #fff;
}
.table-bordered.jetpack-modules tr.jetpack-module td .row-actions {
  float: left;
  padding: 0 0 1px;
  visibility: visible;
}
.table-bordered.jetpack-modules tr.jetpack-module td .row-actions span {
  margin-right: 5px;
}
.table-bordered.jetpack-modules tr.jetpack-module td .row-actions span a {
  opacity: 0;
}
.table-bordered.jetpack-modules tr.jetpack-module td .row-actions span a:focus {
  opacity: 1;
}
@media (max-width: 530px) {
  .table-bordered.jetpack-modules tr.jetpack-module td .row-actions {
    display: none;
  }
}
@media (max-width: 782px) {
  .table-bordered.jetpack-modules tr.jetpack-module td .row-actions {
    display: block;
    padding-right: 10px;
    visibility: visible;
  }
}
.table-bordered.jetpack-modules > thead > tr > th {
  border: 0;
  vertical-align: middle;
}
.table-bordered.jetpack-modules > thead > tr > th:last-child {
  padding-left: 0;
}
@media (max-width: 782px) {
  .table-bordered.jetpack-modules > thead > tr > th:last-child {
    padding-right: 0;
  }
}
.table-bordered.jetpack-modules td {
  background: #fff;
}
.table-bordered.jetpack-modules #doaction {
  margin-top: 0;
}
@media (max-width: 782px) {
  .table-bordered.jetpack-modules #doaction {
    padding: 10px 7px;
  }
}
.table-bordered.jetpack-modules .checkall {
  margin-top: 1px;
}
.table-bordered.jetpack-modules .filter-search {
  margin-top: 8px;
}
.table-bordered.jetpack-modules .genericon {
  color: #999;
  display: none;
  margin: 7px 3px 0;
}
@media (max-width: 900px) {
  .table-bordered.jetpack-modules .genericon {
    display: inline-block;
  }
}
.table-bordered.jetpack-modules .med {
  width: 70px;
}
.table-bordered.jetpack-modules .sm {
  width: 30px;
}
@media (max-width: 782px) {
  .table-bordered.jetpack-modules .check-column {
    width: 50px;
  }
}

.fixed-top .check-column {
  padding: 8px 10px 0 10px;
  width: 2.2em;
}

.wrap {
  margin: 0;
  padding: 0 1.5em 1em;
  overflow: hidden;
}
.wrap h2 {
  font-size: 24px;
  font-weight: 400;
}
.wrap .manage-left {
  float: right;
  margin: 0;
  padding: 0;
  width: 63%;
}
.wrap .manage-left table {
  width: 100%;
}
.wrap .manage-left th {
  font-weight: 400;
}
@media (max-width: 782px) {
  .wrap .manage-left {
    width: 100%;
  }
}
.wrap .manage-right {
  margin: 0;
  padding: 0;
  /*position: absolute;
  right: 0;*/
  float: left;
  width: 35%;
  z-index: 1;
}
.wrap .manage-right p {
  font-size: 12px;
  font-weight: bold;
  color: #bbb;
  padding-top: 2px;
  text-transform: uppercase;
  letter-spacing: 1px;
  clear: right;
}
.wrap .manage-right .bumper {
  margin-right: 33px;
}
.wrap .manage-right.show {
  display: block;
  position: fixed;
  overflow-y: auto;
  overflow-x: hidden;
  position: absolute;
}
.wrap .manage-right .search-bar {
  margin-bottom: 18px;
  max-width: 300px;
}
.wrap .manage-right p.search-box {
  float: none;
  height: auto;
  margin-bottom: 0;
  position: relative;
}
.wrap .manage-right p.search-box input[type='search'] {
  padding: 0 8px;
  width: 90%;
  line-height: initial;
}
@media (max-width: 782px) {
  .wrap .manage-right p.search-box input[type='search'] {
    float: right;
    padding: 9px 8px;
  }
}
.wrap .manage-left p.search-box input[type="submit"] {
  display: none;
}
.wrap .manage-right .button-group .button {
  outline: none;
}
.wrap .manage-right .subsubsub {
  margin: 0;
  padding: 0;
}
.wrap .manage-right .subsubsub a {
  padding: 0;
  line-height: inherit;
}
.wrap .manage-right .subsubsub .current {
  padding: 1px 5px;
  border-radius: 2px;
  margin-right: -5px;
  background: #0D72B2;
  color: #FFF;
}
.wrap .manage-right .subsubsub .current .count {
  color: #BCD7E7;
  font-weight: 200;
}
.wrap .manage-right .subsubsub li {
  display: block;
  text-align: right;
}
@media (max-width: 782px) {
  .wrap .manage-right {
    background: #fff;
    bottom: 0;
    display: none;
    min-width: 300px;
    position: fixed;
    left: 0;
    top: 0;
    z-index: 13;
    box-shadow: 0 1px 20px 5px rgba(0, 0, 0, 0.1);
  }
  .wrap .manage-right .bumper {
    margin: 13px;
  }
  .wrap .manage-right .navbar-form {
    margin: 0;
    padding: 0;
  }
}

/* 'Pages' is a temporary location for these styles, until we can break them up into their proper atmoic locations */
.configure-module p {
  font-size: 14px;
}
.configure-module p.success, .configure-module p.error {
  color: #fff;
  padding: 10px;
}
.configure-module p.success {
  background-color: #81a844;
}
.configure-module p.error {
  background-color: #d94f4f;
}

.protect-status p {
  font-size: 16px;
}
.protect-status strong {
  display: inline-block;
  margin-top: 10px;
  background: #fff;
  padding: 10px;
  border: 1px #ddd solid;
  font-size: 16px;
  color: #000;
  max-width: 100%;
}
.protect-status.attn {
  color: #d94f4f;
}
.protect-status.working {
  color: #81a844;
}

/* Whitelisting */
#non-editable-whitelist {
  margin-top: 15px;
}

.protect-whitelist textarea {
  width: 100%;
  min-height: 150px;
}

#editable-whitelist .whitelist-table {
  width: 100%;
}

/* btns + inputs */
.configure-module input[disabled] {
  opacity: .5;
}
.configure-module input.button-primary {
  font-weight: bold;
}

/* whitelist table */
.whitelist-table {
  border-top: 1px solid;
  border-left: 1px solid;
  border-color: #ddd;
  background-color: #fff;
}
.whitelist-table td, .whitelist-table th {
  padding: 10px;
  margin: 0;
  border-bottom: 1px solid;
  border-right: 1px solid;
  border-color: #ddd;
  font-size: 14px;
}
.whitelist-table th.heading {
  font-weight: bold;
  color: #5d6d74;
  text-align: right;
  background-color: #eee;
}
.whitelist-table td.item-actions {
  border-right: none;
  text-align: left;
}
.whitelist-table .toolbar {
  padding: 0;
}
.whitelist-table .add-btn {
  text-align: center;
  width: 10%;
  border-right: 1px #ddd solid;
}

.ip-address, .enter-ip {
  width: 90%;
  text-align: right;
  vertical-align: middle;
}

.delete-ip-address {
  text-align: center;
  border: 0;
  background: transparent;
  color: #6f7476;
  box-shadow: none;
  font-size: 20px;
  margin: 0;
  padding: 0;
  cursor: pointer;
  border-radius: 2px;
}
.delete-ip-address:hover {
  background: #eee;
}

.toolbar div {
  float: right;
  padding: 10px;
}

@media only screen and (min-width: 1100px) {
  #non-editable-whitelist {
    width: 28%;
    float: left;
    margin-top: 0;
  }

  .protect-whitelist {
    width: 65%;
    float: right;
  }
}
/* end > 1065px */
@media only screen and (max-width: 1130px) {
  .enter-ip input[type="text"] {
    max-width: 175px;
  }
}
/* end < 1130px */
@media only screen and (max-width: 1250px) and (min-width: 1065px), (max-width: 730px) and (min-width: 600px) {
  .enter-ip {
    width: 85%;
  }

  .add-btn {
    width: 15%;
  }
}
/* end < 1250px & > 1065px */
@media only screen and (max-width: 782px) {
  .add-btn {
    text-align: left;
  }

  .add-btn .ip-add {
    margin-top: 4px;
    margin-bottom: 3px;
  }
}
/* end < 782px */
@media only screen and (max-width: 730px) {
  .add-btn {
    text-align: center;
  }
}
/* end < 730px */
@media only screen and (max-width: 665px) and (min-width: 600px) {
  .enter-ip input[type="text"] {
    max-width: 165px;
  }
}
/* end < 665px & > 600px */
@media only screen and (max-width: 600px) {
  .toolbar div {
    width: 100%;
  }

  .add-btn {
    border-top: 1px #ddd solid;
  }

  .enter-ip {
    text-align: center;
  }

  .enter-ip strong {
    display: block;
    margin-bottom: 5px;
  }

  .enter-ip input[type="text"] {
    width: 100%;
    max-width: 100%;
  }

  .add-btn input,
  .enter-ip .button {
    width: 50%;
    margin: 0 auto;
  }

  .enter-ip .button {
    margin-top: 10px;
  }
}
/* end > 600px */
@media only screen and (max-width: 400px) {
  .protect-status strong {
    font-size: 12px;
    overflow: auto;
  }

  .add-btn input,
  .enter-ip .button {
    width: 100%;
  }
}
/* end < 400px */
.jp-content .hide {
  display: none;
}
.jp-content .pointer {
  cursor: pointer;
}
.jp-content .landing {
  margin: 0 auto;
  z-index: 2;
  position: relative;
}
.jp-content h1 {
  font: 300 2.57143em/1em "proxima-nova","Open Sans",Helvetica,Arial,sans-serif;
  position: relative;
  z-index: 3;
  width: 100%;
  text-align: center;
}
.jp-content h1.success {
  color: #81a844;
}
.jp-content .footer {
  padding-top: 0;
  margin-top: 0;
  background-image: none;
}
.jp-content .footer:before {
  height: inherit;
}
.jp-content .more-info:before {
  content: none;
}

.landing .wpcom-connect {
  min-height: 400px;
}

.wpcom-connect .j-col {
  padding: 0;
}
.wpcom-connect .connect-desc {
  padding-left: 25px;
}
.wpcom-connect .connect-btn {
  text-align: center;
}

.module-grid h2 {
  color: #000;
  font: 300 2.57143em/1em "proxima-nova","Open Sans",Helvetica,Arial,sans-serif;
}

.download-jetpack {
  margin-top: 1em !important;
}

#jump-start-area {
  margin-top: 35px;
  padding-right: 60px;
  padding-left: 60px;
  background: #fefefe;
  border: 1px #dae0e2 solid;
  padding-bottom: 20px;
}
#jump-start-area #jumpstart-cta,
#jump-start-area .jumpstart-desc {
  padding: 0;
}
#jump-start-area p {
  font-size: 14px;
  line-height: 185%;
}
#jump-start-area .spinner {
  float: none;
  margin: 0 auto;
  position: absolute;
  bottom: 0;
  height: 100%;
  width: 100%;
  background-position: 50% 56%;
  background-color: rgba(254, 254, 254, 0.99);
  display: block;
  opacity: .9;
}

.jumpstart-message p {
  padding-left: 25px;
}

.jumpstart-desc {
  text-align: right;
}

#jumpstart-cta {
  text-align: center;
}

.dismiss-jumpstart {
  color: #999;
  font-size: 14px;
}

#jumpstart-cta .button,
#jumpstart-cta .button-primary {
  margin: 1em;
  font-size: 18px;
  height: 45px !important;
  padding: 8px 15px 1px;
}

#jumpstart-cta .button-primary {
  display: block;
  margin: 35px 20px 5px 20px;
}

#jp-config-list {
  position: relative;
  padding-top: 15px;
  padding-bottom: 15px;
  margin-right: -15px;
  margin-left: -15px;
}
#jp-config-list .j-col {
  padding: 15px;
}
#jp-config-list strong {
  display: inline-block;
}
#jp-config-list small {
  display: block;
  margin-top: 5px;
  line-height: 150%;
}
#jp-config-list .close {
  position: absolute;
  top: 10px;
  left: 0;
  text-transform: uppercase;
  font-weight: bold;
  display: block;
  z-index: 5;
}

.jp-config-status {
  text-transform: uppercase;
  font-size: 10px;
  font-weight: bold;
  line-height: 100%;
  color: #fff;
  background: #9fbd72;
  border-radius: 2px;
  padding: 2px 4px;
  display: inline-block;
}

.miguel {
  display: none;
  position: fixed;
  opacity: .35;
  bottom: -200px;
  right: 0;
  z-index: 1;
  -webkit-animation: miguel 3.4s 0s ease-in-out;
  animation: miguel 3.4s 0s ease-in-out;
}

.miguel:nth-child(2) {
  right: 49%;
  width: 120px;
  height: 131px;
  -webkit-animation-duration: 2.4s;
  animation-duration: 2.4s;
  -webkit-animation-delay: 0s;
  animation-delay: 0s;
}

.miguel:nth-child(3) {
  right: 23%;
  width: 60px;
  height: 66px;
  -webkit-animation-duration: 4.5s;
  animation-duration: 4.5s;
  -webkit-animation-delay: 0s;
  animation-delay: 0s;
}

@-webkit-keyframes "miguel" {
  0% {
    -webkit-transform: translate3d(0px, 0px, 0px);
    transform: translate3d(0px, 0px, 0px);
  }
  100% {
    -webkit-transform: translate3d(900px, -900px, 0px);
    transform: translate3d(900px, -900px, 0px);
  }
}
@keyframes "miguel" {
  0% {
    -webkit-transform: translate3d(0px, 0px, 0px);
    transform: translate3d(0px, 0px, 0px);
  }
  100% {
    -webkit-transform: translate3d(900px, -900px, 0px);
    transform: translate3d(900px, -900px, 0px);
  }
}
@media (max-width: 1147px) {
  .jp-content .landing {
    padding: 0 2em;
  }
  .jp-content .footer {
    padding-top: 1.5em;
  }
}
@media (max-width: 782px) {
  #jumpstart-cta .button-primary {
    margin: 10px 0 5px 0;
  }

  #jump-start-area .spinner {
    background-position: 50% 35%;
  }
}
@media (max-width: 530px) {
  .jp-content .landing {
    padding: 0 .5em;
  }

  #jump-start-area {
    padding: 0 1em;
  }

  .jumpstart-message p {
    padding-left: 0;
  }

  #jumpstart-cta .button-primary {
    margin: 0 0 5px 0;
    padding-bottom: 10px;
  }

  .footer .a8c-attribution a:after {
    top: 6px;
  }
}
.nav-horizontal:before, .features:before, .modules:before, .load-more:before, .nav-horizontal:after, .features:after, .modules:after, .load-more:after {
  content: "";
  display: table;
}
.nav-horizontal:after, .features:after, .modules:after, .load-more:after {
  clear: both;
}

/*# sourceMappingURL=jetpack-admin.css.map */
.j-row{width:100%;margin:0 auto}.j-row:before,.j-row:after{content:" ";display:table}.j-row:after{clear:both}.j-col{padding:0.85em;width:100%;float:right;position:relative}@media only screen{.j-sm-1{width:8.33333%}.j-sm-2{width:16.66667%}.j-sm-3{width:25%}.j-sm-4{width:33.33333%}.j-sm-5{width:41.66667%}.j-sm-6{width:50%}.j-sm-7{width:58.33333%}.j-sm-8{width:66.66667%}.j-sm-9{width:75%}.j-sm-10{width:83.33333%}.j-sm-11{width:91.66667%}.j-sm-12{width:100%}}@media (min-width: 530px){.j-md-1{width:8.33333%}.j-md-2{width:16.66667%}.j-md-3{width:25%}.j-md-4{width:33.33333%}.j-md-5{width:41.66667%}.j-md-6{width:50%}.j-md-7{width:58.33333%}.j-md-8{width:66.66667%}.j-md-9{width:75%}.j-md-10{width:83.33333%}.j-md-11{width:91.66667%}.j-md-12{width:100%}}@media (min-width: 782px){.j-lrg-1{width:8.33333%}.j-lrg-2{width:16.66667%}.j-lrg-3{width:25%}.j-lrg-4{width:33.33333%}.j-lrg-5{width:41.66667%}.j-lrg-6{width:50%}.j-lrg-7{width:58.33333%}.j-lrg-8{width:66.66667%}.j-lrg-9{width:75%}.j-lrg-10{width:83.33333%}.j-lrg-11{width:91.66667%}.j-lrg-12{width:100%}}body,button,input,select,textarea{color:#222;font-family:"Open Sans",Helvetica,Arial,sans-serif;font-size:14px;line-height:1.4;-webkit-font-smoothing:antialiased}h1,h2,h3,h4,h5,h6{color:#222;clear:both}a{color:#0d72b2;transition:color .2s;text-decoration:none}a:visited{color:#0d72b2}a:hover{color:#0f92e5}a:focus{outline:thin dotted}address{margin:0 0 1.5em}abbr[title],acronym{cursor:help}ins{background:#eee;text-decoration:none}dt{font-weight:700}fieldset{border:0;margin:0;padding:0}textarea{resize:vertical}hr{display:block;height:1px;border:0;border-top:1px solid #ccc;margin:1em 0;padding:0}img{vertical-align:middle}@-webkit-keyframes "grow"{0%{-webkit-transform:scale(0.3);transform:scale(0.3)}60%{-webkit-transform:scale(1.15);transform:scale(1.15)}100%{-webkit-transform:scale(1);transform:scale(1)}}@keyframes "grow"{0%{-webkit-transform:scale(0.3);transform:scale(0.3)}60%{-webkit-transform:scale(1.15);transform:scale(1.15)}100%{-webkit-transform:scale(1);transform:scale(1)}}@-webkit-keyframes "candy"{0%{-webkit-transform:scale(1);transform:scale(1)}20%{-webkit-transform:scale(1.15);transform:scale(1.15)}60%{-webkit-transform:scale(0.95);transform:scale(0.95)}100%{-webkit-transform:scale(1);transform:scale(1)}}@keyframes "candy"{0%{-webkit-transform:scale(1);transform:scale(1)}20%{-webkit-transform:scale(1.15);transform:scale(1.15)}60%{-webkit-transform:scale(0.95);transform:scale(0.95)}100%{-webkit-transform:scale(1);transform:scale(1)}}@-webkit-keyframes "flyer"{0%{-webkit-transform:translate3d(0px, 0px, 0px);transform:translate3d(0px, 0px, 0px)}100%{-webkit-transform:translate3d(680px, -680px, 0px);transform:translate3d(680px, -680px, 0px)}}@keyframes "flyer"{0%{-webkit-transform:translate3d(0px, 0px, 0px);transform:translate3d(0px, 0px, 0px)}100%{-webkit-transform:translate3d(680px, -680px, 0px);transform:translate3d(680px, -680px, 0px)}}.button,.download-jetpack{transition:all .1s ease-in-out}.jp-button,.jp-button--settings{display:inline-block;position:relative;padding:0.76923em 1.46154em;color:#efefef;font:800 0.9285714286em/1 'Open Sans', Helvetica, sans-serif;text-shadow:0 -1px 1px rgba(0,0,0,0.2);background:#6f7476;border-radius:3px}.jp-button:visited,.jp-button--settings:visited{color:#efefef}.jp-button:hover,.jp-button--settings:hover,.jp-button:focus,.jp-button--settings:focus{color:#fff;background:#57972d}.jp-button:active,.jp-button--settings:active{background:#57972d;opacity:0.8}.jp-button--settings{background:#93b45f;color:#e8eedf}.jp-button--settings:visited{color:#e8eedf}.jp-button--settings:hover,.jp-button--settings:focus{background:#9fbd72;color:#fff}.jp-button--settings.current{background:#3c6621;color:#fff;box-shadow:inset 0 2px 0 #365A1F, inset 0 1px 3px #3c6621}.download-jetpack{display:inline-block;position:relative;padding:0.64286em 0.85714em 0.53571em;color:#fff;font:400 20px/1 "proxima-nova", 'Open Sans', Helvetica, sans-serif;background:#518d2a;z-index:3;border-radius:6px;box-shadow:0 6px 0 #3e6c20,0 6px 3px rgba(0,0,0,0.4)}.download-jetpack:visited{color:#fff}.download-jetpack:hover,.download-jetpack:focus{color:#fff;background:#57972d;box-shadow:0 6px 0 #3e6c20,0 6px 3px rgba(0,0,0,0.4)}.download-jetpack:active{top:6px;box-shadow:0 0px 0 #3e6c20,0 0 0 rgba(0,0,0,0.4)}.download-jetpack:active:after{top:-6px}.download-jetpack:before{content:'';display:inline-block;position:relative;top:-2px;margin-left:13px;width:30px;height:30px;vertical-align:middle;background:url("../images/connect-plug.svg") center center no-repeat;background-size:100%}.download-jetpack:after{content:'';position:absolute;top:0;right:0;width:100%;height:100%}@media (max-width: 1147px){.download-jetpack{font-size:1.28571em}.download-jetpack:before{top:-1px;width:23px;height:23px}}@media (max-width: 900px){.download-jetpack:active{top:0}}@media (max-width: 530px){.download-jetpack{font-size:1.21429em;font-weight:600}.download-jetpack:before{width:19px;height:19px;margin-left:9px}}#searchsubmit{display:inline-block;border:none;position:relative;padding:0.71429em 1.5em;color:#efefef;font:800 0.8em/1 'Open Sans', Helvetica, sans-serif;text-shadow:0 -1px 1px rgba(0,0,0,0.2);background:#6f7476;outline:none;border-radius:3px}#searchsubmit:visited{color:#efefef}#searchsubmit:hover,#searchsubmit:focus{color:#fff;background:#2aa0d5}#searchsubmit:active{opacity:0.7}@font-face{font-family:'automatticons';src:url("../_inc/fonts/automatticons/automatticons.eot");src:url("../_inc/fonts/automatticons/automatticons.eot?#iefix") format("embedded-opentype"),url("../_inc/fonts/automatticons/automatticons.woff") format("woff"),url("../_inc/fonts/automatticons/automatticons.ttf") format("truetype"),url("../_inc/fonts/automatticons/automatticons.svg#automatticonsregular") format("svg");font-weight:normal;font-style:normal}@font-face{font-family:"jetpack";src:url("../_inc/fonts/jetpack/jetpack.eot");src:url("../_inc/fonts/jetpack/jetpack.eot?#iefix") format("embedded-opentype"),url("../_inc/fonts/jetpack/jetpack.woff") format("woff"),url("../_inc/fonts/jetpack/jetpack.ttf") format("truetype"),url("../_inc/fonts/jetpack/jetpack.svg#jetpack") format("svg");font-weight:normal;font-style:normal}@media screen and (-webkit-min-device-pixel-ratio: 0){@font-face{font-family:"jetpack";src:url("../_inc/fonts/jetpack/jetpack.svg#jetpack") format("svg")}}.nav-horizontal a{display:inline-block}.nav-horizontal li{position:relative;float:right}.nav-horizontal ul{margin:0;padding:0}*,*:before,*:after{-moz-box-sizing:border-box;box-sizing:border-box}::-moz-selection{background:#91bd51;color:#fff;text-shadow:none}::selection{background:#91bd51;color:#fff;text-shadow:none}#wpbody-content{padding-bottom:0}#wpcontent{margin-right:160px;padding:0}ul#adminmenu a.toplevel_page_jetpack:after{border-left-color:#81a844}.folded #wpcontent{margin-right:36px}#wpfooter{display:none}.jp-content{background:#f9f9f9;margin:0;height:auto;min-height:100%;width:100%;width:100%;-webkit-font-smoothing:antialiased}.jp-content .wrapper{background:#f9f9f9}@media (max-width: 900px){#wpcontent,.auto-fold #wpcontent,.auto-fold #wpfooter,.modal,.configure .frame.top.fixed{margin-right:36px;padding-right:0}}@media (max-width: 782px){#wpcontent,.auto-fold #wpcontent,.auto-fold #wpfooter,.modal,.configure .frame.top.fixed{margin-right:0}}@media (max-width: 782px){.configure .frame.top.fixed{padding-right:0}}.wrap.inner,.page-content{max-width:950px;margin:0 auto}.wrap.inner li,.page-content li{line-height:23px}@media (max-width: 530px){.page-content{margin-top:0}}@media (max-width: 1147px){.wrap.inner{background:#f9f9f9;padding:15px}}@media (max-width: 530px){.wrap.inner{margin-top:1.71429em}}.jetpack_page_jetpack_modules .header-nav{margin:0}.jetpack_page_jetpack_modules .page-content{max-width:1200px;min-height:500px;margin:0}.page-content.about{position:relative;z-index:10}@media (max-width: 1147px){.page-content.about{background:#f9f9f9;padding:15px}}@media (max-width: 1147px){.page-content.configure{background:#f9f9f9}}.footer nav{max-width:550px;margin:0 auto}.header{right:0;left:0;background:#81a844}.header-nav li{line-height:60px}.header-nav a{padding:0 0.71429em;line-height:24px}.header-nav .jetpack-logo a{display:inline-block;position:relative;width:214px;margin-left:6px;background:url(../images/jetpack-logo.png) center center no-repeat;background:url(../images/jetpack-logo.svg) center center no-repeat,none;background-size:183px auto;color:#fff;line-height:60px;font-weight:normal}.header-nav .jetpack-logo a span{text-indent:-9999px;visibility:hidden}.header-nav .jetpack-logo a:before{content:'';position:absolute;top:0;right:0;width:100%;height:100%;background-size:183px 32px}.header-nav .jetpack-modules+.jetpack-modules{margin-right:15px}.main-nav{float:right}.main-nav li{margin:0}@media (max-width: 900px){.main-nav{font-size:13px}}.user-nav{float:left}.user-nav li{margin:0}.jetpack-pagestyles #screen-meta{margin:0}.jetpack-pagestyles #screen-meta-links .screen-meta-toggle{z-index:2}.jetpack-pagestyles #screen-options-link-wrap,.jetpack-pagestyles #contextual-help-link-wrap{border:none}.jetpack-pagestyles .update-nag{display:none}.masthead{position:relative;text-align:center;z-index:1;background-color:#81a844;background-image:linear-gradient(top, #81a844, #8eb74e)}.masthead.hasbutton .flyer{bottom:-270px}.masthead.hasbutton .subhead{margin-top:175px}@media (max-width: 530px){.masthead.hasbutton .subhead{margin-top:105px;padding:0}}.masthead h1,.masthead h2{margin:0 auto}.masthead h1{padding:2.5em 0 1.11111em;max-width:21.94444em;color:#fff;font:300 2.57143em/1.4em "proxima-nova","Open Sans",Helvetica,Arial,sans-serif;position:relative;text-shadow:0 -1px 1px rgba(0,0,0,0.12);z-index:3}.masthead h1+.flyby{margin-top:180px}@media (max-width: 1147px){.masthead h1{padding-top:1.83333em;font-size:2.14286em}}@media (max-width: 782px){.masthead h1{max-width:600px;font-size:28px}}@media (max-width: 530px){.masthead h1{margin:0 15px;padding:31px 0 15px 0;font-size:21px;font-weight:400}}.jetpack-connected .masthead h1{margin-bottom:33px;max-width:600px}.flyby{position:relative;max-width:1200px;margin:0 auto}@media (max-width: 900px){.flyby{display:none}}.flyer{position:absolute;bottom:-200px;right:4%;z-index:1;-webkit-animation:flyer 3.4s 2s ease-in-out;animation:flyer 3.4s 2s ease-in-out}.flyer:nth-child(2){right:49%;width:120px;height:131px;-webkit-animation-delay:4.6s;animation-delay:4.6s;-webkit-animation-duration:2.4s;animation-duration:2.4s}.flyer:nth-child(3){right:23%;width:60px;height:66px;-webkit-animation-delay:5.8s;animation-delay:5.8s;-webkit-animation-duration:4.5s;animation-duration:4.5s}.subhead{position:relative;margin-top:105px;padding:4em 0;background:#f9f9f9;z-index:2}.subhead h2{max-width:460px;color:#5d6d74;font:400 1.57143em/1.4em "proxima-nova","Open Sans",Helvetica,Arial,sans-serif;text-shadow:0 -1px 1px #fff}@media (max-width: 900px){.subhead h2{max-width:428px;font-size:20px}}@media (max-width: 530px){.subhead h2{display:none}}.subhead:after{content:'';position:absolute;bottom:100%;right:0;margin-bottom:-1px;width:100%;height:228px;background:url("../images/the-cloud.svg") center bottom repeat-x;pointer-events:none;z-index:-1}@media (max-width: 1147px){.subhead{margin-top:122px;padding:70px 0 49px}.subhead:after{background-size:160% auto}}@media (max-width: 900px){.subhead{margin-top:122px;padding:70px 0 49px}}@media (max-width: 530px){.subhead{margin-top:83px;padding:47px 15px 39px}}.clouds-sm{height:100px;position:relative;text-align:center;z-index:1;background-color:#81a844;background-image:linear-gradient(top, #81a844, #89b348)}.clouds-sm:after{content:'';position:absolute;bottom:0;right:0;margin-bottom:-1px;width:100%;height:137px;background:url("../images/the-cloud-sm.svg") center bottom repeat-x;pointer-events:none;z-index:2}@media (max-width: 530px){.clouds-sm{height:90px}}.featured{border-top:1px solid #d6d6d6;border-bottom:1px solid #d6d6d6;background:#fff;position:relative;padding:2.0em 1em 4.6em 1em;text-align:center;z-index:1}.featured:before{content:"";display:block;position:absolute;top:0;height:100%;z-index:-1}.featured .features,.featured .modules{margin:0 auto;display:inline-block}@media (max-width: 530px){.featured{display:none}}.featured h2,.module-grid h2{margin-top:1em;color:#5d6d74;font:300 2em/1em "proxima-nova","Open Sans",Helvetica,Arial,sans-serif;text-align:center}@media (max-width: 900px){.featured h2,.module-grid h2{font-size:30px}}@media (max-width: 782px){.featured h2,.module-grid h2{font-size:28px}}.features,.modules{margin:0 -5px}.feature,.module{position:relative;float:right;margin:0 5px 10px;width:310px;transition:all .2s ease-in-out}@media (max-width: 1147px){.feature,.module{margin:.75% 1.5% .75% 0;width:32.333333%;transition:none}.feature:nth-child(3n+1),.module:nth-child(3n+1){margin-right:0}.feature:hover,.module:hover{top:0;box-shadow:none}}.feature{-webkit-transform:translateZ(0);transform:translateZ(0)}.feature h3{margin:0 0 0.58824em;color:#697b84;font-size:1.21429em;line-height:1em;font-weight:800}.feature p{margin:0;color:#6e818a}.feature:before{content:'';position:absolute;bottom:0;right:0;width:100%;height:10px;background:rgba(0,0,0,0.02);z-index:-1;-webkit-transform:translateZ(0);transform:translateZ(0);transition:all .2s ease-in-out}.feature:hover{-webkit-transform:translateY(-5px);-ms-transform:translateY(-5px);transform:translateY(-5px)}.feature:hover h3{color:#1a8dba}.feature:hover .feature-img{border:1px solid #ccc;border-bottom:none}.feature:hover .no-border{border:none}.feature:hover:before{-webkit-transform:translateY(5px);-ms-transform:translateY(5px);transform:translateY(5px)}@media (max-width: 1147px){.feature:hover h3{color:#6e818a}.feature:hover .feature-img{border:1px solid #ddd;border-bottom:none}.feature:hover .no-border{border:none}}.feature .feature-img{padding-top:52%;width:100%;height:auto;border:1px solid #ddd;border-bottom:none}.feature .feature-img.custom-css{background:url("../images/custom-css.jpg") no-repeat;background-size:100% auto}@media print, (-webkit-min-device-pixel-ratio: 1.25), (min--moz-device-pixel-ratio: 1.25), (-o-min-device-pixel-ratio: 5 / 4), (min-resolution: 120dpi){.feature .feature-img.custom-css{background-image:url("../images/custom-css@2x.jpg")}}.feature .feature-img.wordpress-connect{background:url("../images/wordpress-connect.jpg") no-repeat;background-size:100% auto}@media print, (-webkit-min-device-pixel-ratio: 1.25), (min--moz-device-pixel-ratio: 1.25), (-o-min-device-pixel-ratio: 5 / 4), (min-resolution: 120dpi){.feature .feature-img.wordpress-connect{background-image:url("../images/wordpress-connect@2x.jpg")}}.feature .feature-img.wordpress-stats{background:url("../images/wordpress-stats.jpg") no-repeat;background-size:100% auto}@media print, (-webkit-min-device-pixel-ratio: 1.25), (min--moz-device-pixel-ratio: 1.25), (-o-min-device-pixel-ratio: 5 / 4), (min-resolution: 120dpi){.feature .feature-img.wordpress-stats{background-image:url("../images/wordpress-stats@2x.jpg")}}.feature .feature-img.no-border{border:none;padding-bottom:1px}.feature-description{display:block;padding:1em 1.07143em 1.07143em;border:1px solid #ddd;background:#f5f5f5}.feature:hover .feature-description{background:#fff;border-color:#ccc}@media (max-width: 1147px){.feature:hover .feature-description{border:1px solid #ddd;background:#f5f5f5}}@media (max-width: 900px){.feature-description{min-height:115px}}.cat{clear:both;margin-bottom:23px}.cat h3{font-size:24px;font-weight:300;margin:0 6px 13px 0;text-align:right}.cat .clear{clear:both}.module-grid{text-align:center}.module-grid h2{margin:1em 0}@media (max-width: 530px){.module-grid h2{padding-top:16px;margin-top:0;font-size:25px}}#module-search{position:relative;width:100%;max-width:40.71429em;margin:0 auto 1.07143em;overflow:hidden}#jetpack-search{margin:0;padding:11px 16px 11px 16px;width:100%;border:1px solid #c9ced0;border-radius:3px;background:#fff;color:#5c6671;line-height:1.3}#jetpack-search:focus{color:#5c6671;outline:none}#jetpack-search:focus+label{background:transparent;opacity:0}#jetpack-search::-webkit-input-placeholder{color:#a8acae}#jetpack-search :-moz-placeholder{color:#a8acae}#jetpack-search::-moz-placeholder{color:#a8acae}#jetpack-search:-ms-input-placeholder{color:#a8acae}#jetpack-search+label{position:absolute;top:1px;left:1px;bottom:1px;width:48px;color:#abafb1;text-indent:-9999px;pointer-events:none;border-radius:3px;transition:all .2s ease-in-out}#jetpack-search+label:after{content:'\f400';position:absolute;left:11px;text-align:left;top:4px;font-size:1.71429em;font-weight:normal;font-family:"genericons"}.jp-filter{margin-bottom:2.85714em;color:#6f7476}.jp-filter a{display:inline-block;position:relative;padding:0.76923em 1.46154em;color:#aaa;font:600 0.92857em/1 "Open Sans", Helvetica, Arial, sans-serif;text-shadow:0 -1px 1px rgba(255,255,255,0.2);background:#eee;border-radius:3px;background-clip:padding-box}.jp-filter a.selected,.jp-filter a:hover,.jp-filter a:focus{color:#efefef;text-shadow:0 -1px 1px rgba(0,0,0,0.2);background:#6f7476}@media (max-width: 530px){.jp-filter a{padding:0.76em 1em}}.module{display:block;padding:0.71429em 1.07143em 1em;text-align:right;border:1px solid #dae0e2;background:#fff;box-shadow:0 0 0 rgba(0,0,0,0.03);transition:opacity 2s ease-in}.module:hover{border-color:#8ac9e8;background:#f8fcfe}.module h3{cursor:pointer;margin:0 0 0.5em;color:#1a8dba;font-size:1.14286em;line-height:1.4em;font-weight:700}.module p{margin:0;color:#686f72;font-size:0.85714em}.module:hover,.module:focus{border-color:#8ac9e8;background:#f8fcfe}.module.active{border-color:#2ea2cc;box-shadow:inset -4px 0 0 #2ea2cc}.module.active:hover{border-color:#69bedd;box-shadow:inset -4px 0 0 #69bedd}@media (max-width: 1147px){.cat .module:nth-child(3n+1){margin:.75% 1.5% .75% 0}.cat .module:nth-child(3n - 1){margin-right:0}}@media (max-width: 900px){.cat .module{margin:1% 2% 1% 0}.cat .module:nth-child(2n+1){margin:1% 2% 1% 0}.cat .module:nth-child(2n+0){margin-right:0}}@media (max-width: 530px){.cat .module{margin:5px 0}.cat .module:nth-child(2n+1){margin-right:0}.cat .module:nth-child(2n+0){margin-right:0}}@media (max-width: 900px){.module{margin:1% 2% 1% 0;width:49%}.module:nth-child(3n+1){margin-right:2%}.module:nth-child(2n+1){margin-right:0}}@media (max-width: 530px){.module{margin:5px 0;width:100%}.module:nth-child(3n+1){margin-right:0}.module:nth-child(2n+1){margin-right:0}}.new{position:relative}.new:after{content:'NEW';position:absolute;top:-8px;left:-8px;padding-top:10px;width:32px;height:32px;color:#fff;font-size:8px;font-weight:800;text-align:center;text-shadow:0 1px 0 rgba(0,0,0,0.2);background:url("../images/new-badge.svg") center center no-repeat;background-size:100%;border-radius:50%}.paid{display:inline-block;position:relative;top:5px;margin-right:10px;padding:1px 4px 0 6px;height:13px;color:#fff;font:700 10px/1 "Open Sans",Helvetica,Arial,sans-serif;text-shadow:0 1px 0 rgba(0,0,0,0.05);background:#d0d0d0;vertical-align:top}.paid:before,.paid:after{position:absolute;top:0;left:100%;font:normal 14px/14px "genericons"}.paid:before{content:'\f503';color:#d0d0d0;text-shadow:none}.paid:after{content:'\f428';margin-left:-5px;font-size:11px}.rtl .paid:before{content:'\f501'}.load-more{margin:2.71429em 0 6.15385em}.set{display:none}.show.set{display:block}.loading{bottom:50%;position:absolute;top:50%;width:100%}.loading span{color:#999}.modal{background:#fff;position:fixed;top:52px;bottom:20px;left:20px;right:20px;margin-right:160px;display:none;box-shadow:0 1px 20px 5px rgba(0,0,0,0.1);z-index:500}.modal .close{position:absolute;top:0;left:0;font:300 1.71429em "genericons" !important;color:#777;content:'\f405';display:inline-block;padding:0.28571em 0.71429em 0.42857em;z-index:5}.modal .close:hover{background:#eee;opacity:0.8}.modal .close:active{background:#eee;opacity:0.4}.modal #jp-post-flair{display:none}.modal .content-container{position:absolute;top:0;left:0;bottom:0;right:0;overflow:auto;padding:2.14286em}.modal .content{margin:0 auto;max-width:900px;text-align:right}.modal h2{text-align:right;margin-top:0;color:#5d6d74;font:300 32px "proxima-nova","Open Sans",Helvetica,Arial,sans-serif;text-shadow:0 -1px 1px #fff}@media (max-width: 530px){.modal h2{font-size:26px}}.modal h5{clear:right}.modal p{font-size:1.23077em}.modal footer{position:absolute;right:0;bottom:0;width:100%;padding:12px 20px;border-top:1px solid #ddd;background:#fff;text-align:left}.modal footer ul{margin:0}.modal footer li{display:inline-block;margin:0}.modal .button-secondary,.modal .button-primary:active{vertical-align:baseline}@media (max-width: 900px){.modal{bottom:5%;margin-right:36px;font-size:80%}.modal .content{top:38px}}@media (max-width: 782px){.modal{top:66px;margin-right:0}}@media (max-width: 600px){.modal{top:10px;left:10px;bottom:10px;right:10px}}.jp-info-img{float:left;margin:0 30px 30px 0}.jp-info-img img{border:1px solid #ddd;max-width:100%;height:auto}.jp-info-img img:first-child{margin-top:0}@media (max-width: 782px){.jp-info-img{float:none;margin:0 0 15px}}.content-container.modal-footer{bottom:53px}.shade{background:#000;bottom:0;cursor:pointer;display:none;right:0;opacity:0.2;position:fixed;left:0;top:0;z-index:11}.entry-title,.page-template-default h1{margin-top:0.61111em;color:#5d6d74;font:300 2.57143em/1.4em "proxima-nova","Open Sans",Helvetica,Arial,sans-serif;text-shadow:0 -1px 1px #fff}@media (max-width: 530px){.entry-title,.page-template-default h1{font-size:2em}}.blog h3,.single h3,.page-template-default h2{margin-top:0.61111em;color:#5d6d74;font:300 1.9em "proxima-nova","Open Sans",Helvetica,Arial,sans-serif;text-shadow:0 -1px 1px #fff}@media (max-width: 530px){.blog h3,.single h3,.page-template-default h2{font-size:1.4em}}.page-template-default p{line-height:1.71429em}.blog .type-post,.page-template-default .type-page,.single .type-post,.single .type-jetpack_support{float:right;width:70%}.footer{margin-top:1.42857em;position:relative;padding:10em 0 4.28571em;text-align:center}.footer:before,.footer:after{content:'';position:absolute;right:0;pointer-events:none}.footer:before{top:0;margin-top:-1px;width:100%;height:195px}.footer:after{bottom:0;width:100%;height:50px;background:url("../images/the-footcloud.svg") center bottom no-repeat;background-size:auto 45px;z-index:1}.footer .download-jetpack{margin-bottom:33px}@media (max-width: 1147px){.footer{padding-top:165px;padding-bottom:0}.footer:before{background-size:160% auto}.footer:after{display:none}.footer ul{float:none;overflow:hidden}}@media (max-width: 900px){.footer{padding-top:146px}}@media (max-width: 782px){.footer{margin-top:0}}@media (max-width: 530px){.footer{margin-top:0;padding-top:135px}}@media (max-width: 320px){.footer{padding-top:76px}}.footer nav{max-width:100%}.footer nav a,.footer nav a:visited{padding:4px 6px;color:#999}.footer nav a:hover,.footer nav a:focus,.footer nav a:visited:hover,.footer nav a:visited:focus{color:#81A844}@media (max-width: 1147px){.footer nav{border:none;padding:0}.footer nav a:hover,.footer nav a:focus,.footer nav a:visited:hover,.footer nav a:visited:focus{color:#fff}}@media (max-width: 530px){.footer nav li{display:block;float:none;margin:0;text-align:right}.footer nav a{display:block;padding:0 16px;line-height:44px}}.primary{padding:25px 15px 10px 15px;border-bottom:1px solid #eee}.secondary-footer{margin:0 auto}.secondary-footer li{margin-left:5px}@media (max-width: 1147px){.secondary-footer{margin:0 30px;padding:8px 15px 30px}}@media (max-width: 530px){.secondary-footer{margin:0;padding:0;border:none;font-weight:400}.secondary-footer a{border-top:1px solid #eee}}.footer .a8c-attribution{margin:0;padding:0 6px;color:#bbb;font-size:0.78571em;font-family:"Gill Sans","Gill Sans MT","Open Sans",Helvetica,Arial,sans-serif;text-transform:uppercase}.footer .a8c-attribution a{display:inline-block;position:relative;padding:4px 16px;left:9999px;outline:0}.footer .a8c-attribution a:after{content:'A';position:absolute;top:2px;left:-9999px;height:100%;color:#999;font-size:1.54545em;font-family:"automatticons";text-align:center}.footer .a8c-attribution a:hover:after{-webkit-animation:candy .4s ease-in-out;animation:candy .4s ease-in-out}.secondary{padding:10px 15px 0 15px}.jetpack-message{background:#8eb74e;border:1px solid #73963d;margin:33px auto 0;max-width:90%;position:relative;z-index:2}.jetpack-message.is-opt-in{margin:50px 0 0;max-width:100%;padding:10px 15px;background:#fff;border:0;box-shadow:0 1px 1px 0 rgba(0,0,0,0.1);font-size:13px;text-align:center}.subhead .jetpack-message.is-opt-in{margin:0;padding-bottom:0;background:transparent;box-shadow:none}.subhead .jetpack-message.is-opt-in .jp-button,.subhead .jetpack-message.is-opt-in .jp-button--settings{display:inline-block}.jetpack-message.is-opt-in p{color:#3c4549}.jetpack-message.is-opt-in .jp-button,.jetpack-message.is-opt-in .jp-button--settings{margin-top:15px;display:none}.jetpack-message h4{color:#fff;margin:0}.jetpack-message p{color:#fff;margin:0;opacity:0.7}.jetpack-message .squeezer{padding:23px 80px 23px 23px;position:relative;text-align:right}.jetpack-message .squeezer:before{color:#fff;content:'\f418';font-family:'Genericons';font-size:33px;height:33px;right:25px;opacity:0.6;position:absolute;top:23px;top:calc( 50% - 22px )}@media (max-width: 530px){.jetpack-message .squeezer{padding:23px}.jetpack-message .squeezer:before{display:none}}.jetpack-message .squeezer a{color:#FFF;border-bottom:1px solid #D5E4BD}.jetpack-message .squeezer a:hover{border-bottom:1px solid #F1F6E9}.jetpack-message.error .squeezer:before,.jetpack-message.jetpack-err .squeezer:before{content:'\f414'}.configure-module .jetpack-message{max-width:100%}.modules h3.icon,.jetpack-modules .info a{width:auto}.modules h3.icon:before,.jetpack-modules .info a:before{display:inline-block;position:relative;top:1px;right:-3px;margin-left:2px;opacity:0.8;font:normal 20px "genericons";vertical-align:top}.jetpack-modules .info a:before{margin-top:1px}.latex:before,.jetpack-modules #latex .info a:before{content:'\f408'}.carousel:before,.jetpack-modules #carousel .info a:before{content:'\f102'}.modules h3.contact-form:before,.jetpack-modules #contact-form .info a:before{content:'\f175';font:normal 20px "dashicons"}.modules h3.custom-css:before,.jetpack-modules #custom-css .info a:before{content:'\f100';font:normal 20px "dashicons"}.modules h3.enhanced-distribution:before,.jetpack-modules #enhanced-distribution .info a:before{content:'\f237';font:normal 20px "dashicons"}.modules h3.widgets:before,.jetpack-modules #widgets .info a:before{content:'\f116';font:normal 20px "dashicons"}.modules h3.gravatar-hovercards:before,.jetpack-modules #gravatar-hovercards .info a:before{content:'G';font-family:"automatticons"}.infinite-scroll:before,.jetpack-modules #infinite-scroll .info a:before{content:'\f408'}.comments:before,.jetpack-modules #comments .info a:before{content:'\f108'}.sso:before,.jetpack-modules #sso .info a:before{content:'\f205'}.json-api:before,.jetpack-modules #json-api .info a:before{content:'\f415'}.likes:before,.jetpack-modules #likes .info a:before{content:'\f408'}.markdown:before,.jetpack-modules #markdown .info a:before{content:'\f462'}.minileven:before,.jetpack-modules #minileven .info a:before{content:'\f453'}.manage:before,.jetpack-modules #manage .info a:before{content:'\f205'}.monitor:before,.jetpack-modules #monitor .info a:before{content:'\f468'}.notes:before,.jetpack-modules #notes .info a:before{content:'\f300'}.omnisearch:before,.jetpack-modules #omnisearch .info a:before{content:'\f400'}.photon:before,.jetpack-modules #photon .info a:before{content:'\f403'}.post-by-email:before,.jetpack-modules #post-by-email .info a:before{content:'\f410'}.protect:before,.jetpack-modules #protect .info a:before{content:'\f470';position:relative;top:-1px}.modules h3.publicize:before,.jetpack-modules #publicize .info a:before{content:'\f237';font:normal 20px "dashicons"}.related-posts:before,.jetpack-modules #related-posts .info a:before{content:'\f420'}.sharedaddy:before,.jetpack-modules #sharedaddy .info a:before{content:'\f415'}.shortcodes:before,.jetpack-modules #shortcodes .info a:before{content:'\f100'}.verification-tools:before,.jetpack-modules #verification-tools .info a:before{content:'\f425'}.after-the-deadline:before,.jetpack-modules #after-the-deadline .info a:before{content:'\f411'}.subscriptions:before,.jetpack-modules #subscriptions .info a:before{content:'\f410'}.tiled-gallery:before,.jetpack-modules #tiled-gallery .info a:before{content:'\f103'}.modules h3.vaultpress:before,.jetpack-modules #vaultpress .info a:before{content:'V';font-family:"automatticons"}.videopress:before,.jetpack-modules #videopress .info a:before{content:'\f104'}.modules h3.widget-visibility:before,.jetpack-modules #widget-visibility .info a:before{content:'\f116';font:normal 20px "dashicons"}.stats:before,.jetpack-modules #stats .info a:before{content:'\f205'}.shortlinks:before,.jetpack-modules #shortlinks .info a:before{content:'\f107'}.modules h3.custom-content-types:before,.jetpack-modules #custom-content-types .info a:before{content:'\f498';font:normal 20px "dashicons"}.modules h3.site-icon:before,.jetpack-modules #site-icon .info a:before{content:'\f475'}@media (max-width: 782px){.blog .type-post,.page-template-default .type-page,.single .type-post,.single .type-jetpack_support{width:100%}}@media (max-width: 600px){.clouds-sm{display:none}}@media (max-width: 530px){.wrap.inner.jp-support .jp-support-column-left{width:100%}.wrap.inner.jp-support .jp-support-column-left .widget-text{margin-left:0;width:100%}.wrap.inner.jp-support .jp-support-column-right{width:100%}}@media screen and (max-width: 400px){.jp-frame .header-nav{padding-bottom:10px}.jp-frame .header-nav li{line-height:30px}.jp-frame .header-nav .jetpack-logo{width:100%;text-align:center}.jp-frame .header-nav .jetpack-modules{margin:0;width:50%;text-align:left;padding:0 5px}.jp-frame .header-nav .jetpack-modules+.jetpack-modules{text-align:right}}@media (max-width: 320px){.jetpack_page_jetpack_modules .wrap{padding:0 0 1em}}.page-content.configure{margin-top:0}.configure .frame.top{border:none;box-shadow:none;padding-top:1.42857em;position:relative;top:auto}.configure .frame.top.fixed{background:#f9f9f9;border-bottom:1px solid #e9e9e9;padding-right:160px;margin-top:-6px;position:fixed;left:0;top:32px;width:100%;z-index:4;box-shadow:0 2px 2px -2px #eee}@media (max-width: 782px){.configure .frame.top.fixed{border:none;box-shadow:none;padding-top:1.42857em;position:relative;top:auto}}@media (max-width: 600px){.configure .frame.top.fixed{top:0}}.configure .frame.top .tablenav.top{float:right}@media (max-width: 900px){.configure .frame.top .tablenav.top .actions{display:block}}@media (max-width: 782px){.configure .frame.top .tablenav.top .actions{margin-top:6px}}.jp-frame-top-fixed .configure{padding-top:94px}.filter-search{display:none;float:left;margin-top:10px}@media (max-width: 782px){.filter-search{display:block}}@media (max-width: 530px){.filter-search{display:none}}.module-actions.landing-page{float:left;margin-left:15px}.module-actions.landing-page a{font-size:0.6em}.table-bordered.jetpack-modules{border:none;margin-bottom:0}.table-bordered.jetpack-modules tr.jetpack-module th{border-right:0;padding:14px 4px 0}.table-bordered.jetpack-modules tr.jetpack-module th input{display:block}.table-bordered.jetpack-modules tr.jetpack-module:hover .genericon{display:inline-block}.table-bordered.jetpack-modules tr.jetpack-module:hover td .row-actions span a{opacity:1}.table-bordered.jetpack-modules tr.jetpack-module.active th,.table-bordered.jetpack-modules tr.jetpack-module.active td{background:#f7fcfe}.table-bordered.jetpack-modules tr.jetpack-module.active th{border-right:4px solid #2ea2cc;padding-right:0px}.table-bordered.jetpack-modules tr.jetpack-module.active td:first-child{border-right:4px solid #2ea2cc}.table-bordered.jetpack-modules tr.jetpack-module.unavailable{opacity:0.3}.table-bordered.jetpack-modules tr.jetpack-module.unavailable input{display:none}.table-bordered.jetpack-modules tr.jetpack-module#vaultpress{opacity:1}.table-bordered.jetpack-modules tr.jetpack-module th,.table-bordered.jetpack-modules tr.jetpack-module td{background:#fff;margin:0;box-shadow:inset 0 -1px 0 rgba(0,0,0,0.1)}.table-bordered.jetpack-modules tr.jetpack-module td{padding:10px 14px 8px 10px;line-height:25px}.table-bordered.jetpack-modules tr.jetpack-module td:first-child{border-right:4px solid #fff}.table-bordered.jetpack-modules tr.jetpack-module td .row-actions{float:left;padding:0 0 1px;visibility:visible}.table-bordered.jetpack-modules tr.jetpack-module td .row-actions span{margin-right:5px}.table-bordered.jetpack-modules tr.jetpack-module td .row-actions span a{opacity:0}.table-bordered.jetpack-modules tr.jetpack-module td .row-actions span a:focus{opacity:1}@media (max-width: 530px){.table-bordered.jetpack-modules tr.jetpack-module td .row-actions{display:none}}@media (max-width: 782px){.table-bordered.jetpack-modules tr.jetpack-module td .row-actions{display:block;padding-right:10px;visibility:visible}}.table-bordered.jetpack-modules>thead>tr>th{border:0;vertical-align:middle}.table-bordered.jetpack-modules>thead>tr>th:last-child{padding-left:0}@media (max-width: 782px){.table-bordered.jetpack-modules>thead>tr>th:last-child{padding-right:0}}.table-bordered.jetpack-modules td{background:#fff}.table-bordered.jetpack-modules #doaction{margin-top:0}@media (max-width: 782px){.table-bordered.jetpack-modules #doaction{padding:10px 7px}}.table-bordered.jetpack-modules .checkall{margin-top:1px}.table-bordered.jetpack-modules .filter-search{margin-top:8px}.table-bordered.jetpack-modules .genericon{color:#999;display:none;margin:7px 3px 0}@media (max-width: 900px){.table-bordered.jetpack-modules .genericon{display:inline-block}}.table-bordered.jetpack-modules .med{width:70px}.table-bordered.jetpack-modules .sm{width:30px}@media (max-width: 782px){.table-bordered.jetpack-modules .check-column{width:50px}}.fixed-top .check-column{padding:8px 10px 0 10px;width:2.2em}.wrap{margin:0;padding:0 1.5em 1em;overflow:hidden}.wrap h2{font-size:24px;font-weight:400}.wrap .manage-left{float:right;margin:0;padding:0;width:63%}.wrap .manage-left table{width:100%}.wrap .manage-left th{font-weight:400}@media (max-width: 782px){.wrap .manage-left{width:100%}}.wrap .manage-right{margin:0;padding:0;float:left;width:35%;z-index:1}.wrap .manage-right p{font-size:12px;font-weight:bold;color:#bbb;padding-top:2px;text-transform:uppercase;letter-spacing:1px;clear:right}.wrap .manage-right .bumper{margin-right:33px}.wrap .manage-right.show{display:block;position:fixed;overflow-y:auto;overflow-x:hidden;position:absolute}.wrap .manage-right .search-bar{margin-bottom:18px;max-width:300px}.wrap .manage-right p.search-box{float:none;height:auto;margin-bottom:0;position:relative}.wrap .manage-right p.search-box input[type='search']{padding:0 8px;width:90%;line-height:initial}@media (max-width: 782px){.wrap .manage-right p.search-box input[type='search']{float:right;padding:9px 8px}}.wrap .manage-left p.search-box input[type="submit"]{display:none}.wrap .manage-right .button-group .button{outline:none}.wrap .manage-right .subsubsub{margin:0;padding:0}.wrap .manage-right .subsubsub a{padding:0;line-height:inherit}.wrap .manage-right .subsubsub .current{padding:1px 5px;border-radius:2px;margin-right:-5px;background:#0D72B2;color:#FFF}.wrap .manage-right .subsubsub .current .count{color:#BCD7E7;font-weight:200}.wrap .manage-right .subsubsub li{display:block;text-align:right}@media (max-width: 782px){.wrap .manage-right{background:#fff;bottom:0;display:none;min-width:300px;position:fixed;left:0;top:0;z-index:13;box-shadow:0 1px 20px 5px rgba(0,0,0,0.1)}.wrap .manage-right .bumper{margin:13px}.wrap .manage-right .navbar-form{margin:0;padding:0}}.configure-module p{font-size:14px}.configure-module p.success,.configure-module p.error{color:#fff;padding:10px}.configure-module p.success{background-color:#81a844}.configure-module p.error{background-color:#d94f4f}.protect-status p{font-size:16px}.protect-status strong{display:inline-block;margin-top:10px;background:#fff;padding:10px;border:1px #ddd solid;font-size:16px;color:#000;max-width:100%}.protect-status.attn{color:#d94f4f}.protect-status.working{color:#81a844}#non-editable-whitelist{margin-top:15px}.protect-whitelist textarea{width:100%;min-height:150px}#editable-whitelist .whitelist-table{width:100%}.configure-module input[disabled]{opacity:.5}.configure-module input.button-primary{font-weight:bold}.whitelist-table{border-top:1px solid;border-left:1px solid;border-color:#ddd;background-color:#fff}.whitelist-table td,.whitelist-table th{padding:10px;margin:0;border-bottom:1px solid;border-right:1px solid;border-color:#ddd;font-size:14px}.whitelist-table th.heading{font-weight:bold;color:#5d6d74;text-align:right;background-color:#eee}.whitelist-table td.item-actions{border-right:none;text-align:left}.whitelist-table .toolbar{padding:0}.whitelist-table .add-btn{text-align:center;width:10%;border-right:1px #ddd solid}.ip-address,.enter-ip{width:90%;text-align:right;vertical-align:middle}.delete-ip-address{text-align:center;border:0;background:transparent;color:#6f7476;box-shadow:none;font-size:20px;margin:0;padding:0;cursor:pointer;border-radius:2px}.delete-ip-address:hover{background:#eee}.toolbar div{float:right;padding:10px}@media only screen and (min-width: 1100px){#non-editable-whitelist{width:28%;float:left;margin-top:0}.protect-whitelist{width:65%;float:right}}@media only screen and (max-width: 1130px){.enter-ip input[type="text"]{max-width:175px}}@media only screen and (max-width: 1250px) and (min-width: 1065px), (max-width: 730px) and (min-width: 600px){.enter-ip{width:85%}.add-btn{width:15%}}@media only screen and (max-width: 782px){.add-btn{text-align:left}.add-btn .ip-add{margin-top:4px;margin-bottom:3px}}@media only screen and (max-width: 730px){.add-btn{text-align:center}}@media only screen and (max-width: 665px) and (min-width: 600px){.enter-ip input[type="text"]{max-width:165px}}@media only screen and (max-width: 600px){.toolbar div{width:100%}.add-btn{border-top:1px #ddd solid}.enter-ip{text-align:center}.enter-ip strong{display:block;margin-bottom:5px}.enter-ip input[type="text"]{width:100%;max-width:100%}.add-btn input,.enter-ip .button{width:50%;margin:0 auto}.enter-ip .button{margin-top:10px}}@media only screen and (max-width: 400px){.protect-status strong{font-size:12px;overflow:auto}.add-btn input,.enter-ip .button{width:100%}}.jp-content .hide{display:none}.jp-content .pointer{cursor:pointer}.jp-content .landing{margin:0 auto;z-index:2;position:relative}.jp-content h1{font:300 2.57143em/1em "proxima-nova","Open Sans",Helvetica,Arial,sans-serif;position:relative;z-index:3;width:100%;text-align:center}.jp-content h1.success{color:#81a844}.jp-content .footer{padding-top:0;margin-top:0;background-image:none}.jp-content .footer:before{height:inherit}.jp-content .more-info:before{content:none}.landing .wpcom-connect{min-height:400px}.wpcom-connect .j-col{padding:0}.wpcom-connect .connect-desc{padding-left:25px}.wpcom-connect .connect-btn{text-align:center}.module-grid h2{color:#000;font:300 2.57143em/1em "proxima-nova","Open Sans",Helvetica,Arial,sans-serif}.download-jetpack{margin-top:1em !important}#jump-start-area{margin-top:35px;padding-right:60px;padding-left:60px;background:#fefefe;border:1px #dae0e2 solid;padding-bottom:20px}#jump-start-area #jumpstart-cta,#jump-start-area .jumpstart-desc{padding:0}#jump-start-area p{font-size:14px;line-height:185%}#jump-start-area .spinner{float:none;margin:0 auto;position:absolute;bottom:0;height:100%;width:100%;background-position:50% 56%;background-color:rgba(254,254,254,0.99);display:block;opacity:.9}.jumpstart-message p{padding-left:25px}.jumpstart-desc{text-align:right}#jumpstart-cta{text-align:center}.dismiss-jumpstart{color:#999;font-size:14px}#jumpstart-cta .button,#jumpstart-cta .button-primary{margin:1em;font-size:18px;height:45px !important;padding:8px 15px 1px}#jumpstart-cta .button-primary{display:block;margin:35px 20px 5px 20px}#jp-config-list{position:relative;padding-top:15px;padding-bottom:15px;margin-right:-15px;margin-left:-15px}#jp-config-list .j-col{padding:15px}#jp-config-list strong{display:inline-block}#jp-config-list small{display:block;margin-top:5px;line-height:150%}#jp-config-list .close{position:absolute;top:10px;left:0;text-transform:uppercase;font-weight:bold;display:block;z-index:5}.jp-config-status{text-transform:uppercase;font-size:10px;font-weight:bold;line-height:100%;color:#fff;background:#9fbd72;border-radius:2px;padding:2px 4px;display:inline-block}.miguel{display:none;position:fixed;opacity:.35;bottom:-200px;right:0;z-index:1;-webkit-animation:miguel 3.4s 0s ease-in-out;animation:miguel 3.4s 0s ease-in-out}.miguel:nth-child(2){right:49%;width:120px;height:131px;-webkit-animation-duration:2.4s;animation-duration:2.4s;-webkit-animation-delay:0s;animation-delay:0s}.miguel:nth-child(3){right:23%;width:60px;height:66px;-webkit-animation-duration:4.5s;animation-duration:4.5s;-webkit-animation-delay:0s;animation-delay:0s}@-webkit-keyframes "miguel"{0%{-webkit-transform:translate3d(0px, 0px, 0px);transform:translate3d(0px, 0px, 0px)}100%{-webkit-transform:translate3d(900px, -900px, 0px);transform:translate3d(900px, -900px, 0px)}}@keyframes "miguel"{0%{-webkit-transform:translate3d(0px, 0px, 0px);transform:translate3d(0px, 0px, 0px)}100%{-webkit-transform:translate3d(900px, -900px, 0px);transform:translate3d(900px, -900px, 0px)}}@media (max-width: 1147px){.jp-content .landing{padding:0 2em}.jp-content .footer{padding-top:1.5em}}@media (max-width: 782px){#jumpstart-cta .button-primary{margin:10px 0 5px 0}#jump-start-area .spinner{background-position:50% 35%}}@media (max-width: 530px){.jp-content .landing{padding:0 .5em}#jump-start-area{padding:0 1em}.jumpstart-message p{padding-left:0}#jumpstart-cta .button-primary{margin:0 0 5px 0;padding-bottom:10px}.footer .a8c-attribution a:after{top:6px}}.nav-horizontal:before,.features:before,.modules:before,.load-more:before,.nav-horizontal:after,.features:after,.modules:after,.load-more:after{content:"";display:table}.nav-horizontal:after,.features:after,.modules:after,.load-more:after{clear:both}

/*# sourceMappingURL=jetpack-admin.min.css.map */