<?php
/**
 * User Dashboard About administration panel.
 *
 * @package WordPress
 * @subpackage Administration
 * @since 3.4.0
 */

/** Load WordPress Administration Bootstrap */
require_once( dirname( __FILE__ ) . '/admin.php' );

require( ABSPATH . 'wp-admin/about.php' );
