/*!
* Do not modify this file directly.  It is compiled Sass code.
* @see: jetpack/_inc/jetpack.scss
*/
#message.jp-banner {
  position: relative;
  margin-bottom: 26px;
  padding: 17px 44px 17px 0;
  border: none;
  background: #81a844;
  color: #fff;
  overflow: hidden;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
#message.jp-banner:after {
  content: '';
  position: absolute;
  bottom: 0;
  right: -100px;
  width: 100%;
  height: 50px;
  background: url("../images/the-footcloud.svg") right bottom no-repeat;
  pointer-events: none;
  z-index: 1;
}
@media (max-width: 830px) {
  #message.jp-banner:after {
    display: none;
  }
}
#message.jp-banner a {
  color: #fff;
}
#message.jp-banner h4 {
  display: block;
  margin: 0;
  padding: 0;
  color: #fff;
  font-size: 20px;
  line-height: 1.3;
  font-weight: normal;
}
#message.jp-banner h4 + p {
  margin-top: 10px;
}

.jp-banner a {
  padding: 0;
}

#message .jp-banner__content {
  color: #dfffcc;
  padding: 0 0 0 20px;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  width: 75%;
}
#message .jp-banner__content.is-connection {
  width: 50%;
}
@media (max-width: 768px) {
  #message .jp-banner__content {
    width: 100%;
  }
  #message .jp-banner__content.is-connection {
    width: 100%;
  }
}
#message .jp-banner__content a {
  background-image: linear-gradient(to bottom, transparent 75%, #fff 50%);
  background-repeat: repeat-x;
  background-size: 2px 2px;
  background-position: 0 1.2em;
}
@media not all, only screen and (min-resolution: 2dppx), only screen and (-webkit-min-device-pixel-ratio: 2) {
  #message .jp-banner__content a {
    background-image: linear-gradient(to bottom, transparent 75%, #fff 75%);
    background-repeat: repeat-x;
  }
}
#message .jp-banner__content p {
  margin: 0;
  padding: 0;
  line-height: 1.5;
}

#message .jp-banner__action-container {
  position: absolute;
  top: 0;
  right: 0;
  padding-left: 20px;
  width: 25%;
  height: 100%;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
@media (max-width: 768px) {
  #message .jp-banner__action-container {
    position: static;
    margin: 14px 0 9px;
    width: 100%;
  }
}
#message .jp-banner__action-container.is-full-width {
  position: static;
  margin: 14px 0 9px;
  width: 100%;
  height: auto;
}
#message .jp-banner__action-container.is-connection {
  width: 50%;
}
@media (max-width: 768px) {
  #message .jp-banner__action-container.is-connection {
    width: 100%;
  }
}

#message .jp-banner__button {
  display: inline-block;
  position: absolute;
  top: 50%;
  right: 125px;
  margin-top: -23px;
  padding: 0.57143em 0.85714em 0.38095em 0.57143em;
  border-radius: 6px;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  background: #518d2a;
  box-shadow: 0 4px 0 #3e6c20, 0 2px 3px rgba(0, 0, 0, 0.2);
  font: 400 1.5em/1 'Open Sans', Helvetica, sans-serif;
  transition: all .1s ease-in-out;
}
@media (max-width: 1080px) {
  #message .jp-banner__button {
    font-size: 1.25em;
    right: 110px;
  }
}
@media (max-width: 830px) {
  #message .jp-banner__button {
    right: 45px;
  }
}
@media (max-width: 768px) {
  #message .jp-banner__button {
    position: static;
    margin: 0;
  }
}
@media (max-width: 420px) {
  #message .jp-banner__button {
    display: block;
    width: 100%;
    text-align: center;
    font-size: 1.1em;
    right: 0;
  }
}
#message .jp-banner__button:hover, #message .jp-banner__button:focus {
  box-shadow: 0 4px 0 #3e6c20, 0 2px 3px rgba(0, 0, 0, 0.2);
}
#message .jp-banner__button:active {
  outline: none;
  -webkit-transform: translateY(2px);
  -ms-transform: translateY(2px);
  transform: translateY(2px);
  box-shadow: 0 0px 0 #3e6c20, 0 0 0 rgba(0, 0, 0, 0.2);
}
#message .jp-banner__button:active:after {
  top: -2px;
}
#message .jp-banner__button:before {
  content: '';
  display: inline-block;
  position: relative;
  vertical-align: middle;
  background: url("../images/connect-plug.svg") center center no-repeat;
  background-size: 100%;
  top: -2px;
  margin-right: 13px;
  width: 22px;
  height: 22px;
}
@media (max-width: 420px) {
  #message .jp-banner__button:before {
    display: none;
  }
}

#message .is-full-width .jp-banner__button {
  position: static;
  margin: 0;
}

#message .is-opt-in .jp-banner__button:before {
  content: "\f147";
  width: 20px;
  height: 20px;
  background: none;
  font: normal 20px/1 Dashicons;
}

#message .jp-banner__dismiss {
  position: absolute;
  top: 0;
  right: 0;
  width: 44px;
  height: 44px;
  text-align: center;
  z-index: 99;
}
#message .jp-banner__dismiss:before {
  color: #a7c979;
  content: '\f158';
  font: normal 20px/44px 'dashicons';
}
#message .jp-banner__dismiss:hover {
  opacity: 0.8;
}
#message .jp-banner__dismiss:active {
  opacity: 1;
  outline: none;
}

/*# sourceMappingURL=jetpack-banners.css.map */