/**
 * Jetpack Portfolio Shortcode
 */

.site .portfolio-entry {
	margin-bottom: 1.6em;
}

.site .portfolio-entry-title,
.site .portfolio-entry-meta,
.site .portfolio-entry-content {
	font-size: 1.2rem;
	font-size: 12px;
	line-height: 1.5;
}

.site .portfolio-featured-image + .portfolio-entry-title {
	margin-top: 0.75em;
	margin-bottom: 0.75em;
}

.site .portfolio-entry-meta {
	font-family: "Noto Sans", sans-serif;
}

.site .portfolio-entry-content .more-link:after {
	font-size: 16px;
	top: 1px;
}

/**
 * Jetpack Widgets
 */

/* Blog Subscriptions Widget */
.jetpack_subscription_widget #subscribe-email input {
	padding: 0.375em;
	width: 100%;
}

.jetpack_subscription_widget form > :last-child {
	margin-bottom: 0;
}

/* Display WordPress Posts Widget */
.widget_jetpack_display_posts_widget .jetpack-display-remote-posts {
	margin: 0;
}

.widget_jetpack_display_posts_widget .jetpack-display-remote-posts h4 {
	font-size: inherit;
	margin: 0 0 1.6em;
}

.widget_jetpack_display_posts_widget .jetpack-display-remote-posts img {
	margin: 0 0 1.6em;
}

.widget_jetpack_display_posts_widget .jetpack-display-remote-posts p {
	font-size: inherit;
	line-height: 1.6 !important;
	margin: 0 0 1.6em !important;
}

.widget_jetpack_display_posts_widget .jetpack-display-remote-posts > :last-child {
	margin-bottom: 0 !important;
}

/* Gallery Widget */
.widget-gallery .slideshow-window {
	border-radius: 0;
}

/* Gravatar Profile Widget */
.widget-area .widget-grofile .grofile-thumbnail {
	border-radius: 50%;
	max-width: 200px;
}

.widget-area .widget-grofile h4 {
	margin: 1.6em 0 0;
}

.widget-area .widget-grofile .grofile-accounts {
	margin-top: 0.8em;
}

/* Image Widget */
.widget_image .wp-caption {
	margin-bottom: 0;
}

.widget_image .wp-caption-text {
	padding-bottom: 0;
}

/* RSS Links Widget */
.widget_rss_links img {
	position: relative;
	top: -2px;
}


/* List type widgets */
.widget_rss_links ul,
.widget_top-posts ul ,
.widget_upcoming_events_widget ul {
	list-style: none;
	margin: 0;
}

.widget_rss_links li,
.widget_top-posts li,
.widget_upcoming_events_widget li {
	border-top: 1px solid #eaeaea;
	border-top: 1px solid rgba(51, 51, 51, 0.1);
	padding: 0.7667em 0;
}

.widget_rss_links li:first-child,
.widget_top-posts li:first-child,
.widget_upcoming_events_widget li:first-child {
	border-top: 0;
	padding-top: 0;
}

.widget_rss_links li:last-child,
.widget_top-posts li:last-child,
.widget_upcoming_events_widget li:last-child {
	padding-bottom: 0;
}


/**
 * Shortcodes Embeds
 */

/* Facebook */
.fb_iframe_widget {
	margin-bottom: 1.6em;
	max-width: 100%;
}

.fb_iframe_widget span {
	max-width: 100%;
}

/* Gist */
.gist table {
	table-layout: auto;
}

.site .gist .gist-file {
	margin-bottom: 1.5em;
}

/* Googlemaps */
.googlemaps {
	margin-bottom: 1.6em;
}

.googlemaps iframe {
	margin-bottom: 0;
}

/* Polldaddy */
.PDS_Poll {
	display: block !important;
	margin-bottom: 1.6em;
}

.PDS_Poll .pds-box {
	max-width: 100%;
	width: auto;
}

/* Presentation */
.site .presentation-wrapper {
	margin: 0 auto 1.6em;
}

/* Recipes */
.site .jetpack-recipe {
	border: 0;
	margin: 0 0 1.6em;
	padding: 0;
}

.site .jetpack-recipe-title {
	border: 0;
	margin-top: 0;
	padding: 0;
}

.site .jetpack-recipe .jetpack-recipe-meta {
	font-size: inherit;
	margin: 0;
}

/* Slideshow */
.site .slideshow-window {
	border-radius: 0;
	margin-bottom: 1.6em;
}

/* Twitter-timeline */
iframe[id*="twitter-widget-"] {
	display: block;
}

/* Vine */
.vine-embed {
	display: block;
}

/* VideoPress */
.site .video-player {
	margin-bottom: 1.6em;
	padding: 0;
}

.video-player object {
	margin-bottom: 0;
}


/**
 * Tiled gallery
 */

.site .tiled-gallery {
	margin-bottom: 1.6em;
}


/**
 * Responsive Videos
 */

.jetpack-video-wrapper {
	margin-bottom: 1.6em;
}

.jetpack-video-wrapper > embed,
.jetpack-video-wrapper > iframe,
.jetpack-video-wrapper > object,
.jetpack-video-wrapper > .wp-video {
	margin-bottom: 0;
}


/**
 * Jetpack Comments
 */

.comment-form iframe {
	margin: 0;
}

.comment-form .subscribe-label {
	font-weight: 400;
	text-transform: none;
}

.comment-subscription-form {
	font-size: 12px;
	font-size: 1.2rem;
	line-height: 1.5em;
	margin: 2em 0 0;
}

.comment-subscription-form + .comment-subscription-form  {
	margin-top: 1em;
}


/**
 * Sharing
 */

.hentry div.sharedaddy h3.sd-title,
.hentry h3.sd-title {
	font-family: "Noto Sans", sans-serif;
	font-size: 12px;
	font-size: 1.2rem;
	line-height: 1;
	margin: 0 0 1em 0;
	opacity: 0.7;
	text-transform: uppercase;
}


/**
 * Related Posts
 */

.hentry #jp-relatedposts {
	margin: 0;
	padding-top: 0;
}

.hentry .jp-relatedposts-post-title a {
	border-bottom: 0;
}

.hentry .jp-relatedposts-headline em:before {
	opacity: 0.7;
}

.hentry div#jp-relatedposts h3.jp-relatedposts-headline {
	font-family: "Noto Sans", sans-serif;
	font-size: 12px;
	font-size: 1.2rem;
	opacity: 0.7;
	text-transform: uppercase;
}

.hentry div#jp-relatedposts div.jp-relatedposts-items-visual {
	margin-left: 0;
}

.hentry div#jp-relatedposts div.jp-relatedposts-items .jp-relatedposts-post {
	margin-bottom: 1.6em;
	opacity: 1;
}

.hentry div#jp-relatedposts div.jp-relatedposts-items-visual h4.jp-relatedposts-post-title,
.hentry div#jp-relatedposts div.jp-relatedposts-items p {
	font-size: 1.2rem;
	font-size: 12px;
	line-height: 1.5;
}

.hentry .jp-relatedposts-post-title {
	font-weight: 700;
}

.hentry div#jp-relatedposts div.jp-relatedposts-items .jp-relatedposts-post .jp-relatedposts-post-title a {
	font-weight: inherit;
}

.hentry div#jp-relatedposts div.jp-relatedposts-items div.jp-relatedposts-post:hover .jp-relatedposts-post-title a,
.hentry div#jp-relatedposts div.jp-relatedposts-items .jp-relatedposts-post .jp-relatedposts-post-title a {
	text-decoration: none;
}

.hentry div#jp-relatedposts div.jp-relatedposts-items .jp-relatedposts-post .jp-relatedposts-post-context,
.hentry div#jp-relatedposts div.jp-relatedposts-items-visual div.jp-relatedposts-post-nothumbs p.jp-relatedposts-post-excerpt {
	opacity: 0.7;
}

.hentry .jp-relatedposts-post-img {
	margin-bottom: 0.6em;
}


/**
 * Stats
 */

#wpstats {
	display: none;
}


/**
 * Media Queries
 */

@media screen and (min-width: 46.25em) {
	.site .portfolio-entry {
		margin-bottom: 1.6471em;
	}

	.site .portfolio-entry-title,
	.site .portfolio-entry-meta,
	.site .portfolio-entry-content {
		font-size: 1.4rem;
		font-size: 14px;
	}

	.site .portfolio-entry-content .more-link:after {
		top: 3px;
	}

	.site .hentry .gist .gist-file {
		margin-bottom: 1.75em;
	}

	.site .widget .gist .gist-file {
		margin-bottom: 1.3125em;
	}

	.hentry .fb_iframe_widget,
	.hentry .googlemaps,
	.hentry .PDS_Poll,
	.site .hentry .presentation-wrapper,
	.site .hentry .jetpack-recipe,
	.site .hentry .slideshow-window,
	.site .hentry .video-player {
		margin-bottom: 1.6471em;
	}

	.widget .fb_iframe_widget,
	.widget .googlemaps,
	.widget .PDS_Poll,
	.site .widget .presentation-wrapper,
	.site .widget .jetpack-recipe,
	.site .widget .slideshow-window,
	.site .widget .video-player {
		margin-bottom: 1.5em;
	}

	.widget_jetpack_display_posts_widget .jetpack-display-remote-posts h4,
	.widget_jetpack_display_posts_widget .jetpack-display-remote-posts img {
		margin: 0 0 1.5em;
	}

	.widget_jetpack_display_posts_widget .jetpack-display-remote-posts p {
		line-height: 1.5 !important;
		margin: 0 0 1.5em !important;
	}

	.widget-area .widget-grofile h4 {
		margin: 1.5em 0 0;
	}

	.widget-area .widget-grofile .grofile-accounts {
		margin-top: 0.75em;
	}

	.jetpack_subscription_widget #subscribe-email input {
		padding: 0.5625em;
	}

	.widget_rss_links li,
	.widget_top-posts li,
	.widget_upcoming_events_widget li {
		padding: 0.9643em 0;
	}

	.site .tiled-gallery {
		margin-bottom: 1.6471em;
	}

	.jetpack-video-wrapper {
		margin-bottom: 1.6471em;
	}

	.comment-subscription-form {
		font-size: 14px;
		font-size: 1.4rem;
	}

	.hentry div#jp-relatedposts div.jp-relatedposts-items .jp-relatedposts-post {
		margin-bottom: 0;
	}

	.hentry div#jp-relatedposts div.jp-relatedposts-items-visual h4.jp-relatedposts-post-title,
	.hentry div#jp-relatedposts div.jp-relatedposts-items p {
		font-size: 1.4rem;
		font-size: 14px;
	}

	.jp-relatedposts-post-img {
		margin-bottom: 0.6176em;
	}
}

@media screen and (min-width: 55em) {
	.site .portfolio-entry {
		margin-bottom: 1.6842em
	}

	.site .portfolio-entry-title,
	.site .portfolio-entry-meta,
	.site .portfolio-entry-content {
		font-size: 1.6rem;
		font-size: 16px;
	}

	.site .portfolio-entry-content .more-link:after {
		font-size: 24px;
		top: 0;
	}

	.site .hentry .gist .gist-file {
		margin-bottom: 2em;
	}

	.site .widget .gist .gist-file {
		margin-bottom: 1.5em;
	}

	.hentry .fb_iframe_widget,
	.hentry .googlemaps,
	.hentry .PDS_Poll,
	.site .hentry .presentation-wrapper,
	.site .hentry .jetpack-recipe,
	.site .hentry .slideshow-window,
	.site .hentry .video-player {
		margin-bottom: 1.6842em;
	}

	.site .tiled-gallery {
		margin-bottom: 1.6842em;
	}

	.jetpack_subscription_widget #subscribe-email input {
		padding: 0.75em;
	}

	.widget_rss_links li,
	.widget_top-posts li,
	.widget_upcoming_events_widget li {
		padding: 0.7188em 0;
	}

	.jetpack-video-wrapper {
		margin-bottom: 1.6842em;
	}

	.comment-subscription-form {
		font-size: 16px;
		font-size: 1.6rem;
	}

	.hentry div#jp-relatedposts div.jp-relatedposts-items-visual h4.jp-relatedposts-post-title,
	.hentry div#jp-relatedposts div.jp-relatedposts-items p {
		font-size: 1.6rem;
		font-size: 16px;
		line-height: 1.5em;
	}

	.jp-relatedposts-post-img {
		margin-bottom: 0.6315em;
	}
}

@media screen and (min-width: 59.6875em) {
	.site .portfolio-entry {
		margin-bottom: 1.6em
	}

	.site .portfolio-entry-title,
	.site .portfolio-entry-meta,
	.site .portfolio-entry-content {
		font-size: 1.2rem;
		font-size: 12px;
	}

	.site .portfolio-entry-content .more-link:after {
		font-size: 16px;
		top: 1px;
	}

	.site .hentry .gist .gist-file {
		margin-bottom: 1.5em;
	}

	.site .widget .gist .gist-file {
		margin-bottom: 1.125em;
	}

	.hentry .fb_iframe_widget,
	.hentry .googlemaps,
	.hentry .PDS_Poll,
	.site .hentry .presentation-wrapper,
	.site .hentry .jetpack-recipe,
	.site .hentry .slideshow-window,
	.site .hentry .video-player {
		margin-bottom: 1.6em;
	}

	.site .tiled-gallery {
		margin-bottom: 1.6em;
	}

	.jetpack_subscription_widget #subscribe-email input {
		padding: 0.4583em;
	}

	.jetpack-video-wrapper {
		margin-bottom: 1.6em;
	}

	.widget-area .widget-grofile .grofile-thumbnail {
		max-width: 100%;
	}

	.widget_rss_links li,
	.widget_top-posts li,
	.widget_upcoming_events_widget li {
		padding: 0.4583em 0;
	}

	.comment-subscription-form {
		font-size: 12px;
		font-size: 1.2rem;
	}

	.hentry div#jp-relatedposts div.jp-relatedposts-items-visual h4.jp-relatedposts-post-title,
	.hentry div#jp-relatedposts div.jp-relatedposts-items p {
		font-size: 1.2rem;
		font-size: 12px;
		line-height: 1.5;
	}

	.jp-relatedposts-post-img {
		margin-bottom: 0.6em;
	}
}

@media screen and (min-width: 68.75em) {
	.site .portfolio-entry {
		margin-bottom: 1.6471em
	}

	.site .portfolio-entry-title,
	.site .portfolio-entry-meta,
	.site .portfolio-entry-content {
		font-size: 1.4rem;
		font-size: 14px;
	}

	.site .portfolio-entry-content .more-link:after {
		top: 3px;
	}

	.site .hentry .gist .gist-file {
		margin-bottom: 1.75em;
	}

	.site .widget .gist .gist-file {
		margin-bottom: 1.3125em;
	}

	.hentry .fb_iframe_widget,
	.hentry .googlemaps,
	.hentry .PDS_Poll,
	.site .hentry .presentation-wrapper,
	.site .hentry .jetpack-recipe,
	.site .hentry .slideshow-window,
	.site .hentry .video-player {
		margin-bottom: 1.6471em;
	}

	.site .tiled-gallery {
		margin-bottom: 1.6471em;
	}

	.jetpack_subscription_widget #subscribe-email input {
		padding: 0.5em;
	}

	.widget_rss_links li,
	.widget_top-posts li,
	.widget_upcoming_events_widget li {
		padding: 0.4643em 0;
	}

	.jetpack-video-wrapper {
		margin-bottom: 1.6471em;
	}

	.comment-subscription-form {
		font-size: 14px;
		font-size: 1.4rem;
	}

	.hentry div#jp-relatedposts div.jp-relatedposts-items-visual h4.jp-relatedposts-post-title,
	.hentry div#jp-relatedposts div.jp-relatedposts-items p {
		font-size: 14px;
		font-size: 1.4rem;
	}

	.jp-relatedposts-post-img {
		margin-bottom: 0.6176em;
	}
}

@media screen and (min-width: 77.5em) {
	.site .portfolio-entry {
		margin-bottom: 1.6842em
	}

	.site .portfolio-entry-title,
	.site .portfolio-entry-meta,
	.site .portfolio-entry-content {
		font-size: 1.6rem;
		font-size: 16px;
	}

	.site .portfolio-entry-content .more-link:after {
		font-size: 24px;
		top: 0;
	}

	.site .hentry .gist .gist-file {
		margin-bottom: 2em;
	}

	.site .widget .gist .gist-file {
		margin-bottom: 1.5em;
	}

	.hentry .fb_iframe_widget,
	.hentry .googlemaps,
	.hentry .PDS_Poll,
	.site .hentry .presentation-wrapper,
	.site .hentry .jetpack-recipe,
	.site .hentry .slideshow-window,
	.site .hentry .video-player {
		margin-bottom: 1.6842em;
	}

	.widget_rss_links li,
	.widget_top-posts li,
	.widget_upcoming_events_widget li {
		padding: 0.4688em 0;
	}

	.site .tiled-gallery {
		margin-bottom: 1.6842em;
	}

	.jetpack-video-wrapper {
		margin-bottom: 1.6842em;
	}

	.hentry div.sharedaddy h3.sd-title,
	.hentry div#jp-relatedposts h3.jp-relatedposts-headline {
		font-size: 13px;
		font-size: 1.3rem;
	}

	.comment-subscription-form {
		font-size: 16px;
		font-size: 1.6rem;
	}

	.hentry div#jp-relatedposts div.jp-relatedposts-items-visual h4.jp-relatedposts-post-title,
	.hentry div#jp-relatedposts div.jp-relatedposts-items p {
		font-size: 16px;
		font-size: 1.6rem;
		line-height: 1.5em;
	}

	.jp-relatedposts-post-img {
		margin-bottom: 0.6315em;
	}
}