/* This file was automatically generated on Feb 02 2015 20:24:19 */

.contact-form .clear-form { clear: both; }
.contact-form input[type='text'], .contact-form input[type='email'] { width: 300px; max-width: 98%; margin-bottom: 13px; }
.contact-form select { margin-bottom: 13px; }
.contact-form textarea { height: 200px; width: 80%; float: none; margin-bottom: 13px; }
.contact-form input[type='radio'], .contact-form input[type='checkbox'] { float: none; margin-bottom: 13px; }
.contact-form label { margin-bottom: 3px; float: none; font-weight: bold; display: block; }
.contact-form label.checkbox, .contact-form label.radio { margin-bottom: 3px; float: none; font-weight: bold; display: inline-block; }
.contact-form label span { color: #AAA; margin-right: 4px; font-weight: normal; }
.form-errors .form-error-message { color: red; }
.textwidget .contact-form input[type='text'], .textwidget .contact-form input[type='email'], .textwidget .contact-form textarea { width: 250px; max-width: 100%; box-sizing: border-box; }
#jetpack-check-feedback-spam { margin: 1px 0px 0px 8px; }
.jetpack-check-feedback-spam-spinner { display: inline-block; margin-top: 7px; }
