//
// Icon Font: jetpack
//

@font-face {
	font-family: "jetpack";
	src: url("../_inc/fonts/jetpack/jetpack.eot");
	src: url("../_inc/fonts/jetpack/jetpack.eot?#iefix") format("embedded-opentype"),
		url("../_inc/fonts/jetpack/jetpack.woff") format("woff"),
		url("../_inc/fonts/jetpack/jetpack.ttf") format("truetype"),
		url("../_inc/fonts/jetpack/jetpack.svg#jetpack") format("svg");
	font-weight: normal;
	font-style: normal;
}

@media screen and (-webkit-min-device-pixel-ratio:0) {
	@font-face {
		font-family: "jetpack";
		src: url("../_inc/fonts/jetpack/jetpack.svg#jetpack") format("svg");
	}
}

// .jetpack-icon-20:before { content: "\f102"; }