<?php
/**
 * New Zealand States
 *
 * @author      WooThemes
 * @category    i18n
 * @package     WooCommerce/i18n
 * @version     2.3.0
 */
global $states;

$states['NZ'] = array(
	'NL' => __( 'Northland', 'woocommerce' ),
	'AK' => __( 'Auckland', 'woocommerce' ),
	'WA' => __( 'Waikato', 'woocommerce' ),
	'BP' => __( 'Bay of Plenty', 'woocommerce' ),
	'TK' => __( 'Taranaki', 'woocommerce' ),
	'HB' => __( 'Hawke&rsquo;s Bay', 'woocommerce' ),
	'MW' => __( 'Manawatu-Wanganui', 'woocommerce' ),
	'WE' => __( 'Wellington', 'woocommerce' ),
	'NS' => __( 'Nelson', 'woocommerce' ),
	'MB' => __( 'Marlborough', 'woocommerce' ),
	'TM' => __( 'Tasman', 'woocommerce' ),
	'WC' => __( 'West Coast', 'woocommerce' ),
	'CT' => __( 'Canterbury', 'woocommerce' ),
	'OT' => __( 'Otago', 'woocommerce' ),
	'SL' => __( 'Southland', 'woocommerce'),
	'GI' => __( 'Gisborne', 'woocommerce' ),
);

