<?php
/**
 * Turkey States
 *
 * @author      WooThemes
 * @category    i18n
 * @package     WooCommerce/i18n
 * @version     2.0.0
 */
global $states;

$states['TR'] = array(
	'TR01' => __( 'Adana', 'woocommerce' ),
	'TR02' => __( 'Ad&#305;yaman', 'woocommerce' ),
	'TR03' => __( 'Afyon', 'woocommerce' ),
	'TR04' => __( 'A&#287;r&#305;', 'woocommerce' ),
	'TR05' => __( 'Amasya', 'woocommerce' ),
	'TR06' => __( 'Ankara', 'woocommerce' ),
	'TR07' => __( 'Antalya', 'woocommerce' ),
	'TR08' => __( 'Artvin', 'woocommerce' ),
	'TR09' => __( 'Ayd&#305;n', 'woocommerce' ),
	'TR10' => __( 'Bal&#305;kesir', 'woocommerce' ),
	'TR11' => __( 'Bilecik', 'woocommerce' ),
	'TR12' => __( 'Bing&#246;l', 'woocommerce' ),
	'TR13' => __( 'Bitlis', 'woocommerce' ),
	'TR14' => __( 'Bolu', 'woocommerce' ),
	'TR15' => __( 'Burdur', 'woocommerce' ),
	'TR16' => __( 'Bursa', 'woocommerce' ),
	'TR17' => __( '&#199;anakkale', 'woocommerce' ),
	'TR18' => __( '&#199;ank&#305;r&#305;', 'woocommerce' ),
	'TR19' => __( '&#199;orum', 'woocommerce' ),
	'TR20' => __( 'Denizli', 'woocommerce' ),
	'TR21' => __( 'Diyarbak&#305;r', 'woocommerce' ),
	'TR22' => __( 'Edirne', 'woocommerce' ),
	'TR23' => __( 'Elaz&#305;&#287;', 'woocommerce' ),
	'TR24' => __( 'Erzincan', 'woocommerce' ),
	'TR25' => __( 'Erzurum', 'woocommerce' ),
	'TR26' => __( 'Eski&#351;ehir', 'woocommerce' ),
	'TR27' => __( 'Gaziantep', 'woocommerce' ),
	'TR28' => __( 'Giresun', 'woocommerce' ),
	'TR29' => __( 'G&#252;m&#252;&#351;hane', 'woocommerce' ),
	'TR30' => __( 'Hakkari', 'woocommerce' ),
	'TR31' => __( 'Hatay', 'woocommerce' ),
	'TR32' => __( 'Isparta', 'woocommerce' ),
	'TR33' => __( '&#304;&#231;el', 'woocommerce' ),
	'TR34' => __( '&#304;stanbul', 'woocommerce' ),
	'TR35' => __( '&#304;zmir', 'woocommerce' ),
	'TR36' => __( 'Kars', 'woocommerce' ),
	'TR37' => __( 'Kastamonu', 'woocommerce' ),
	'TR38' => __( 'Kayseri', 'woocommerce' ),
	'TR39' => __( 'K&#305;rklareli', 'woocommerce' ),
	'TR40' => __( 'K&#305;r&#351;ehir', 'woocommerce' ),
	'TR41' => __( 'Kocaeli', 'woocommerce' ),
	'TR42' => __( 'Konya', 'woocommerce' ),
	'TR43' => __( 'K&#252;tahya', 'woocommerce' ),
	'TR44' => __( 'Malatya', 'woocommerce' ),
	'TR45' => __( 'Manisa', 'woocommerce' ),
	'TR46' => __( 'Kahramanmara&#351;', 'woocommerce' ),
	'TR47' => __( 'Mardin', 'woocommerce' ),
	'TR48' => __( 'Mu&#287;la', 'woocommerce' ),
	'TR49' => __( 'Mu&#351;', 'woocommerce' ),
	'TR50' => __( 'Nev&#351;ehir', 'woocommerce' ),
	'TR51' => __( 'Ni&#287;de', 'woocommerce' ),
	'TR52' => __( 'Ordu', 'woocommerce' ),
	'TR53' => __( 'Rize', 'woocommerce' ),
	'TR54' => __( 'Sakarya', 'woocommerce' ),
	'TR55' => __( 'Samsun', 'woocommerce' ),
	'TR56' => __( 'Siirt', 'woocommerce' ),
	'TR57' => __( 'Sinop', 'woocommerce' ),
	'TR58' => __( 'Sivas', 'woocommerce' ),
	'TR59' => __( 'Tekirda&#287;', 'woocommerce' ),
	'TR60' => __( 'Tokat', 'woocommerce' ),
	'TR61' => __( 'Trabzon', 'woocommerce' ),
	'TR62' => __( 'Tunceli', 'woocommerce' ),
	'TR63' => __( '&#350;anl&#305;urfa', 'woocommerce' ),
	'TR64' => __( 'U&#351;ak', 'woocommerce' ),
	'TR65' => __( 'Van', 'woocommerce' ),
	'TR66' => __( 'Yozgat', 'woocommerce' ),
	'TR67' => __( 'Zonguldak', 'woocommerce' ),
	'TR68' => __( 'Aksaray', 'woocommerce' ),
	'TR69' => __( 'Bayburt', 'woocommerce' ),
	'TR70' => __( 'Karaman', 'woocommerce' ),
	'TR71' => __( 'K&#305;r&#305;kkale', 'woocommerce' ),
	'TR72' => __( 'Batman', 'woocommerce' ),
	'TR73' => __( '&#350;&#305;rnak', 'woocommerce' ),
	'TR74' => __( 'Bart&#305;n', 'woocommerce' ),
	'TR75' => __( 'Ardahan', 'woocommerce' ),
	'TR76' => __( 'I&#287;d&#305;r', 'woocommerce' ),
	'TR77' => __( 'Yalova', 'woocommerce' ),
	'TR78' => __( 'Karab&#252;k', 'woocommerce' ),
	'TR79' => __( 'Kilis', 'woocommerce' ),
	'TR80' => __( 'Osmaniye', 'woocommerce' ),
	'TR81' => __( 'D&#252;zce', 'woocommerce' ),
);
