<?php
/**
 * Bulgarian states
 *
 * @author      WooThemes
 * @category    i18n
 * @package     WooCommerce/i18n
 * @version     2.0.0
 */
global $states;

$states['BG'] = array(
	'BG-01' => __( 'Blagoevgrad', 'woocommerce' ),
	'BG-02' => __( 'Burgas', 'woocommerce' ),
	'BG-08' => __( 'Dobrich', 'woocommerce' ),
	'BG-07' => __( 'Gabrovo', 'woocommerce' ),
	'BG-26' => __( 'Haskovo', 'woocommerce' ),
	'BG-09' => __( 'Kardzhali', 'woocommerce' ),
	'BG-10' => __( 'Kyustendil', 'woocommerce' ),
	'BG-11' => __( 'Lovech', 'woocommerce' ),
	'BG-12' => __( 'Montana', 'woocommerce' ),
	'BG-13' => __( 'Pazardzhik', 'woocommerce' ),
	'BG-14' => __( 'Pernik', 'woocommerce' ),
	'BG-15' => __( 'Pleven', 'woocommerce' ),
	'BG-16' => __( 'Plovdiv', 'woocommerce' ),
	'BG-17' => __( 'Razgrad', 'woocommerce' ),
	'BG-18' => __( 'Ruse', 'woocommerce' ),
	'BG-27' => __( 'Shumen', 'woocommerce' ),
	'BG-19' => __( 'Silistra', 'woocommerce' ),
	'BG-20' => __( 'Sliven', 'woocommerce' ),
	'BG-21' => __( 'Smolyan', 'woocommerce' ),
	'BG-23' => __( 'Sofia', 'woocommerce' ),
	'BG-22' => __( 'Sofia-Grad', 'woocommerce' ),
	'BG-24' => __( 'Stara Zagora', 'woocommerce' ),
	'BG-25' => __( 'Targovishte', 'woocommerce' ),
	'BG-03' => __( 'Varna', 'woocommerce' ),
	'BG-04' => __( 'Veliko Tarnovo', 'woocommerce' ),
	'BG-05' => __( 'Vidin', 'woocommerce' ),
	'BG-06' => __( 'Vratsa', 'woocommerce' ),
	'BG-28' => __( 'Yambol', 'woocommerce' ),
);
