/**
 * activation.scss
 * Styles applied to elements displayed on activation
 */

/**
 * Imports
 */
@import "bourbon";

/**
 * Styling begins
 */
.woocommerce-message {
	overflow: hidden;
	position: relative;
	border-left-color: #cc99c2 !important;
}

p.woocommerce-actions,
.woocommerce-message {
	a.button-primary {
		background: #cc99c2;
		border-color: #b366a4;
		-webkit-box-shadow: inset 0 1px 0 rgba(255,255,255,.25),0 1px 0 rgba(0,0,0,.15);
		box-shadow: inset 0 1px 0 rgba(255,255,255,.25),0 1px 0 rgba(0,0,0,.15);
		color: #fff;

		&:hover {
			background: #bb77ae;
			border-color: #aa559a;
			-webkit-box-shadow: inset 0 1px 0 rgba(255,255,255,.25),0 1px 0 rgba(0,0,0,.15);
			box-shadow: inset 0 1px 0 rgba(255,255,255,.25),0 1px 0 rgba(0,0,0,.15);
		}

		&:active {
			background: #aa559a;
			border-color: #aa559a;
		}
	}

	a.skip,
	a.docs {
		opacity: 0.5;
		text-decoration: none !important;

		&:hover, &:focus {
			opacity: 1;
		}
	}

	a.button-primary,
	a.button-secondary {
		text-decoration: none !important;
	}

	.twitter-share-button {
		margin-top: -3px;
		margin-left: 3px;
		vertical-align: middle;
	}
}

p.woocommerce-actions,
.woocommerce-about-text {
	margin-bottom: 1em !important;
}
