/**
 * Styles for the Site Logo control.
 */
#customize-control-site_logo .current {
	margin-bottom: 6px;
}

#customize-control-site_logo .current span {
	border: 1px solid #eee;
	-webkit-border-radius: 2px;
	border-radius:         2px;
	color: #555;
	display: block;
	overflow: hidden;
	line-height: 40px;
	min-height: 40px;
	padding: 0 6px;
	text-align: center;
	text-overflow: ellipsis;
	white-space: nowrap;
}

#customize-control-site_logo .current img {
	max-width: 100%;
}

#customize-control-site_logo button.new,
#customize-control-site_logo button.change,
#customize-control-site_logo button.remove {
	height: auto;
	width: 48%;
	white-space: normal;
}

#customize-control-site_logo .remove {
	float: left;
	margin-right: 3px;
}

#customize-control-site_logo .new,
#customize-control-site_logo .change {
	float: right;
}

#customize-control-site_logo .customize-control-description {
	display: block;
	clear: both;
	margin-bottom: 10px;
}