/* =Infinite Scroll
-------------------------------------------------------------- */

.infinite-wrap {
	border-top: 0;
}

/* Spinner */
.infinite-loader {
	background-color: #e8e5ce;
	padding: 40px 0;
}
.infinite-loader .spinner {
	margin: 0 auto;
	width: 34px;
	height: 34px;
}
.sidebar .infinite-loader .spinner {
	padding-right: 376px;
}
.rtl.sidebar .infinite-loader .spinner {
	padding-left: 376px;
	padding-right: 0;
}

/* Click-to-load */
#infinite-handle {
	background-color: #e8e5ce;
	padding: 40px 0;
	text-align: center;
}
.sidebar #infinite-handle {
	padding-right: 376px;
}
.rtl.sidebar #infinite-handle {
	padding-left: 376px;
	padding-right: 0;
}
#infinite-handle span {
	background: #e05d22; /* Old browsers */
	background: -webkit-linear-gradient(top, #e05d22 0%, #d94412 100%); /* Chrome 10+, Safari 5.1+ */
	background:   linear-gradient(to bottom, #e05d22 0%, #d94412 100%); /* W3C */
	border: none;
	border-bottom: 3px solid #b93207;
	border-radius: 2px;
	display: inline-block;
	color: #fff;
	font-size: 100%;
	padding: 11px 24px 10px;
	text-decoration: none;
}
#infinite-handle span:hover {
	background: #ed6a31; /* Old browsers */
	background: -webkit-linear-gradient(top, #ed6a31 0%, #e55627 100%); /* Chrome 10+, Safari 5.1+ */
	background:   linear-gradient(to bottom, #ed6a31 0%, #e55627 100%); /* W3C */
	outline: none;
}
#infinite-handle span:active {
	background: #d94412; /* Old browsers */
	background: -webkit-linear-gradient(top, #d94412 0%, #e05d22 100%); /* Chrome 10+, Safari 5.1+ */
	background:   linear-gradient(to bottom, #d94412 0%, #e05d22 100%); /* W3C */
	border: none;
	border-top: 3px solid #b93207;
	padding: 10px 24px 11px;
}

/* Elements to hide: post navigation, normal footer. */
.infinite-scroll .paging-navigation,
.infinite-scroll.neverending #colophon {
	display: none;
}

/* Hooks to infinity-end body class to restore footer. */
.infinity-end.neverending #colophon {
	display: block;
}

/* For small viewports. */
@media (max-width: 999px) {
	.sidebar .infinite-loader .spinner,
	.rtl.sidebar .infinite-loader .spinner {
		padding-right: 0;
		padding-left: 0;
	}
	.infinite-scroll #infinite-handle,
	.rtl.sidebar #infinite-handle {
		padding-right: 0;
		padding-left: 0;
	}
}