<?php
/**
 * Japan States
 *
 * @author      WooThemes
 * @category    i18n
 * @package     WooCommerce/i18n
 * @version     2.0.0
 */
global $states;

$states['JP'] = array(
	'JP01' => __( 'Hokkaido', 'woocommerce' ),
	'JP02' => __( 'Aomori', 'woocommerce' ),
	'JP03' => __( 'Iwate', 'woocommerce' ),
	'JP04' => __( 'Miyagi', 'woocommerce' ),
	'JP05' => __( 'Akita', 'woocommerce' ),
	'JP06' => __( 'Yamagata', 'woocommerce' ),
	'JP07' => __( 'Fukushima', 'woocommerce' ),
	'JP08' => __( 'Ibaraki', 'woocommerce' ),
	'JP09' => __( 'Tochigi', 'woocommerce' ),
	'JP10' => __( 'Gunma', 'woocommerce' ),
	'JP11' => __( 'Saitama', 'woocommerce' ),
	'JP12' => __( 'Chiba', 'woocommerce' ),
	'JP13' => __( 'Tokyo', 'woocommerce' ),
	'JP14' => __( 'Kanagawa', 'woocommerce' ),
	'JP15' => __( 'Niigata', 'woocommerce' ),
	'JP16' => __( 'Toyama', 'woocommerce' ),
	'JP17' => __( 'Ishikawa', 'woocommerce' ),
	'JP18' => __( 'Fukui', 'woocommerce' ),
	'JP19' => __( 'Yamanashi', 'woocommerce' ),
	'JP20' => __( 'Nagano', 'woocommerce' ),
	'JP21' => __( 'Gifu', 'woocommerce' ),
	'JP22' => __( 'Shizuoka', 'woocommerce' ),
	'JP23' => __( 'Aichi', 'woocommerce' ),
	'JP24' => __( 'Mie', 'woocommerce' ),
	'JP25' => __( 'Shiga', 'woocommerce' ),
	'JP26' => __( 'Kyouto', 'woocommerce' ),
	'JP27' => __( 'Osaka', 'woocommerce' ),
	'JP28' => __( 'Hyougo', 'woocommerce' ),
	'JP29' => __( 'Nara', 'woocommerce' ),
	'JP30' => __( 'Wakayama', 'woocommerce' ),
	'JP31' => __( 'Tottori', 'woocommerce' ),
	'JP32' => __( 'Shimane', 'woocommerce' ),
	'JP33' => __( 'Okayama', 'woocommerce' ),
	'JP34' => __( 'Hiroshima', 'woocommerce' ),
	'JP35' => __( 'Yamaguchi', 'woocommerce' ),
	'JP36' => __( 'Tokushima', 'woocommerce' ),
	'JP37' => __( 'Kagawa', 'woocommerce' ),
	'JP38' => __( 'Ehime', 'woocommerce' ),
	'JP39' => __( 'Kochi', 'woocommerce' ),
	'JP40' => __( 'Fukuoka', 'woocommerce' ),
	'JP41' => __( 'Saga', 'woocommerce' ),
	'JP42' => __( 'Nagasaki', 'woocommerce' ),
	'JP43' => __( 'Kumamoto', 'woocommerce' ),
	'JP44' => __( 'Oita', 'woocommerce' ),
	'JP45' => __( 'Miyazaki', 'woocommerce' ),
	'JP46' => __( 'Kagoshima', 'woocommerce' ),
	'JP47' => __( 'Okinawa', 'woocommerce' ),
);
