<?php
/**
 * Malaysian states
 *
 * @author      WooThemes
 * @category    i18n
 * @package     WooCommerce/i18n
 * @version     2.0.0
 */
global $states;

$states['MY'] = array(
	'JHR' => __( 'Johor', 'woocommerce' ),
	'KDH' => __( 'Kedah', 'woocommerce' ),
	'KTN' => __( 'Kelantan', 'woocommerce' ),
	'MLK' => __( 'Melaka', 'woocommerce' ),
	'NSN' => __( 'Negeri Sembilan', 'woocommerce' ),
	'PHG' => __( 'Pahang', 'woocommerce' ),
	'PRK' => __( 'Perak', 'woocommerce' ),
	'PLS' => __( 'Perlis', 'woocommerce' ),
	'PNG' => __( 'Pulau Pinang', 'woocommerce' ),
	'SBH' => __( 'Sabah', 'woocommerce' ),
	'SWK' => __( 'Sarawak', 'woocommerce' ),
	'SGR' => __( 'Selangor', 'woocommerce' ),
	'TRG' => __( 'Terengganu', 'woocommerce' ),
	'KUL' => __( 'W.P. Kuala Lumpur', 'woocommerce' ),
	'LBN' => __( 'W.P. Labuan', 'woocommerce' ),
	'PJY' => __( 'W.P. Putrajaya', 'woocommerce' )
);
